package flink.zanxiangnet.ad.monitoring.clickhouse.sink;

import flink.zanxiangnet.ad.monitoring.pojo.entity.CostHourDM;
import lombok.extern.slf4j.Slf4j;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.sink.RichSinkFunction;

import java.sql.PreparedStatement;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Properties;

@Slf4j
public class BatchSinkHour extends RichSinkFunction<CostHourDM> {

    private Connection connection = null;

    public BatchSinkHour() {
    }

    @Override
    public void open(Configuration config) throws Exception {
        super.open(config);
        Properties props = new Properties();
        props.load(BatchSinkHour.class.getResourceAsStream("/application.properties"));
        connection = ClickhouseUtil.getConn(props);
    }

    @Override
    public void invoke(CostHourDM costhour, Context context) throws SQLException {
        String sql = "insert into data_monitoring.cost_hour " +
                "(dt,\n" +
                "create_time,\n" +
                "`hour`,\n" +
                "ad_id,\n" +
                "adgroup_id,\n" +
                "adcreative_id,\n" +
                "account_id,\n" +
                "campaign_id,\n" +
                "cost_total,\n" +
                "cost_day,\n" +
                "cost_hour,\n" +
                "cost_diff,\n" +
                "cost_last_hour,\n" +
                "cost_last_hour_diff,\n" +
                "cost_last_two_hour,\n" +
                "cost_last_two_hour_diff,\n" +
                "cost_last_three_trend,\n" +
                "cost_speed,\n" +
                "view_count_total,\n" +
                "view_count_day,\n" +
                "view_count_hour,\n" +
                "thousand_display_price_all,\n" +
                "thousand_display_price_day,\n" +
                "thousand_display_price_hour,\n" +
                "valid_click_count_total,\n" +
                "valid_click_count_day,\n" +
                "valid_click_count_hour,\n" +
                "ctr_all,\n" +
                "ctr_day,\n" +
                "ctr_hour,\n" +
                "cpc_all,\n" +
                "cpc_day,\n" +
                "cpc_hour,\n" +
                "conversions_count_total,\n" +
                "conversions_count_day,\n" +
                "conversions_count_hour,\n" +
                "conversions_cost_total,\n" +
                "conversions_cost_day,\n" +
                "conversions_cost_hour,\n" +
                "conversions_rate_all,\n" +
                "conversions_rate_day,\n" +
                "conversions_rate_hour,\n" +
                "first_day_order_roi_total,\n" +
                "first_day_order_roi_day,\n" +
                "first_day_order_roi_hour,\n" +
                "first_day_order_amount_total,\n" +
                "first_day_order_amount_day,\n" +
                "first_day_order_amount_hour,\n" +
                "first_day_order_count_total,\n" +
                "first_day_order_count_day,\n" +
                "first_day_order_count_hour,\n" +
                "web_order_amount_total,\n" +
                "web_order_amount_day,\n" +
                "web_order_amount_hour,\n" +
                "web_order_cost_total,\n" +
                "web_order_cost_day,\n" +
                "web_order_cost_hour,\n" +
                "web_order_rate_total,\n" +
                "web_order_rate_day,\n" +
                "web_order_rate_hour,\n" +
                "web_order_count_total,\n" +
                "web_order_count_day,\n" +
                "web_order_count_hour,\n" +
                "order_roi_total,\n" +
                "order_roi_day,\n" +
                "order_roi_hour,\n" +
                "order_unit_price_total,\n" +
                "order_unit_price_day,\n" +
                "order_unit_price_hour,\n" +
                "from_follow_uv_total,\n" +
                "from_follow_uv_day,\n" +
                "from_follow_uv_hour,\n" +
                "from_follow_cost_total,\n" +
                "from_follow_cost_day,\n" +
                "from_follow_cost_hour,\n" +
                "from_follow_rate_total,\n" +
                "from_follow_rate_day,\n" +
                "from_follow_rate_hour,\n" +
                "web_register_count_total,\n" +
                "web_register_count_day,\n" +
                "web_register_count_hour,\n" +
                "web_register_uv_total,\n" +
                "web_register_uv_day,\n" +
                "web_register_uv_hour,\n" +
                "web_register_cost_total,\n" +
                "web_register_cost_day,\n" +
                "web_register_cost_hour,agency_account_id) values " +
                "(?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?,?,?,\n" +
                "?,?,?,?,?,?,?,?)";
        PreparedStatement preparedStatement = connection.prepareStatement(sql);
        preparedStatement.setString(1, costhour.getDt());
        preparedStatement.setString(2, costhour.getCreateTime());
        preparedStatement.setString(3, costhour.getHour());
        preparedStatement.setString(4, costhour.getAdId());
        preparedStatement.setString(5, costhour.getAdgroupId());
        preparedStatement.setString(6, costhour.getAdcreativeId());
        preparedStatement.setString(7, costhour.getAccountId());
        preparedStatement.setString(8, costhour.getCampaignId());
        preparedStatement.setLong(9, costhour.getCostTotal());
        preparedStatement.setLong(10, costhour.getCostDay());
        preparedStatement.setLong(11, costhour.getCostHour());
        preparedStatement.setLong(12, costhour.getCostDiff());
        preparedStatement.setLong(13, costhour.getCostLastHour());
        preparedStatement.setLong(14, costhour.getCostLastHourDiff());
        preparedStatement.setLong(15, costhour.getCostLastTwoHour());
        preparedStatement.setLong(16, costhour.getCostLastTwoHourDiff());
        preparedStatement.setLong(17, costhour.getCostLastThreeTrend());
        preparedStatement.setDouble(18, costhour.getCostSpeed());
        preparedStatement.setLong(19, costhour.getViewCountTotal());
        preparedStatement.setLong(20, costhour.getViewCountDay());
        preparedStatement.setLong(21, costhour.getViewCountHour());
        preparedStatement.setLong(22, costhour.getThousandDisplayPriceAll());
        preparedStatement.setLong(23, costhour.getThousandDisplayPriceDay());
        preparedStatement.setLong(24, costhour.getThousandDisplayPriceHour());
        preparedStatement.setLong(25, costhour.getValidClickCountTotal());
        preparedStatement.setLong(26, costhour.getValidClickCountDay());
        preparedStatement.setLong(27, costhour.getValidClickCountHour());
        preparedStatement.setDouble(28, costhour.getCtrAll());
        preparedStatement.setDouble(29, costhour.getCtrDay());
        preparedStatement.setDouble(30, costhour.getCtrHour());
        preparedStatement.setLong(31, costhour.getCpcAll());
        preparedStatement.setLong(32, costhour.getCpcDay());
        preparedStatement.setLong(33, costhour.getCpcHour());
        preparedStatement.setLong(34, costhour.getConversionsCountTotal());
        preparedStatement.setLong(35, costhour.getConversionsCountDay());
        preparedStatement.setLong(36, costhour.getConversionsCountHour());
        preparedStatement.setLong(37, costhour.getConversionsCostTotal());
        preparedStatement.setLong(38, costhour.getConversionsCostDay());
        preparedStatement.setLong(39, costhour.getConversionsCostHour());
        preparedStatement.setDouble(40, costhour.getConversionsRateAll());
        preparedStatement.setDouble(41, costhour.getConversionsRateDay());
        preparedStatement.setDouble(42, costhour.getConversionsRateHour());
        preparedStatement.setDouble(43, costhour.getFirstDayOrderRoiTotal());
        preparedStatement.setDouble(44, costhour.getFirstDayOrderRoiDay());
        preparedStatement.setDouble(45, costhour.getFirstDayOrderRoiHour());
        preparedStatement.setLong(46, costhour.getFirstDayOrderAmountTotal());
        preparedStatement.setLong(47, costhour.getFirstDayOrderAmountDay());
        preparedStatement.setLong(48, costhour.getFirstDayOrderAmountHour());
        preparedStatement.setLong(49, costhour.getFirstDayOrderCountTotal());
        preparedStatement.setLong(50, costhour.getFirstDayOrderCountDay());
        preparedStatement.setLong(51, costhour.getFirstDayOrderCountHour());
        preparedStatement.setLong(52, costhour.getWebOrderAmountTotal());
        preparedStatement.setLong(53, costhour.getWebOrderAmountDay());
        preparedStatement.setLong(54, costhour.getWebOrderAmountHour());
        preparedStatement.setLong(55, costhour.getWebOrderCostTotal());
        preparedStatement.setLong(56, costhour.getWebOrderCostDay());
        preparedStatement.setLong(57, costhour.getWebOrderCostHour());
        preparedStatement.setDouble(58, costhour.getWebOrderRateTotal());
        preparedStatement.setDouble(59, costhour.getWebOrderRateDay());
        preparedStatement.setDouble(60, costhour.getWebOrderRateHour());
        preparedStatement.setLong(61, costhour.getWebOrderCountTotal());
        preparedStatement.setLong(62, costhour.getWebOrderCountDay());
        preparedStatement.setLong(63, costhour.getWebOrderCountHour());
        preparedStatement.setDouble(64, costhour.getOrderRoiTotal());
        preparedStatement.setDouble(65, costhour.getOrderRoiDay());
        preparedStatement.setDouble(66, costhour.getOrderRoiHour());
        preparedStatement.setLong(67, costhour.getOrderUnitPriceTotal());
        preparedStatement.setLong(68, costhour.getOrderUnitPriceDay());
        preparedStatement.setLong(69, costhour.getOrderUnitPriceHour());
        preparedStatement.setLong(70, costhour.getFromFollowUvTotal());
        preparedStatement.setLong(71, costhour.getFromFollowUvDay());
        preparedStatement.setLong(72, costhour.getFromFollowUvHour());
        preparedStatement.setLong(73, costhour.getFromFollowCostTotal());
        preparedStatement.setLong(74, costhour.getFromFollowCostDay());
        preparedStatement.setLong(75, costhour.getFromFollowCostHour());
        preparedStatement.setDouble(76, costhour.getFromFollowRateTotal());
        preparedStatement.setDouble(77, costhour.getFromFollowRateDay());
        preparedStatement.setDouble(78, costhour.getFromFollowRateHour());
        preparedStatement.setLong(79, costhour.getWebRegisterCountTotal());
        preparedStatement.setLong(80, costhour.getWebRegisterCountDay());
        preparedStatement.setLong(81, costhour.getWebRegisterCountHour());
        preparedStatement.setLong(82, costhour.getWebRegisterUvTotal());
        preparedStatement.setLong(83, costhour.getWebRegisterUvDay());
        preparedStatement.setLong(84, costhour.getWebRegisterUvHour());
        preparedStatement.setDouble(85, costhour.getWebRegisterCostTotal());
        preparedStatement.setDouble(86, costhour.getWebRegisterCostDay());
        preparedStatement.setDouble(87, costhour.getWebRegisterCostHour());
        preparedStatement.setString(88, costhour.getAgencyAccountId());
        preparedStatement.addBatch();
        preparedStatement.executeBatch();
        connection.commit();
        //clickhouse 处理重复数据
        //TODO:数据去重有问题，去除掉非最新的数据
//        Statement statement_duplicate = connection.createStatement();
//        String sql_duplicate = "optimize table data_monitoring.cost_hour final;";
//        statement_duplicate.executeQuery(sql_duplicate);
//        connection.commit();

    }

    @Override
    public void close() throws Exception {

        super.close();
    }
}
