package flink.zanxiangnet.ad.monitoring.pojo.entity;

import com.aliyun.odps.data.Record;
import com.google.gson.annotations.SerializedName;
import com.zanxiangnet.module.util.DateUtil;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeColumn;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import flink.zanxiangnet.ad.monitoring.util.NumberUtil;
import flink.zanxiangnet.ad.monitoring.util.ObjectUtil;
import lombok.Data;
import org.springframework.beans.BeanUtils;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.Date;

@Data
@MaxComputeTable("ad_stat_of_day_dwd")
public class AdStatOfDayDWD implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 统计日 yyyy-MM-dd（用于 MaxCompute分区）
     */
    @MaxComputeColumn(isPartitioned = true)
    @SerializedName("stat_day")
    private String statDay;

    /**
     * 应用下的账号 id
     */
    @SerializedName("account_id")
    private Long accountId;

    /**
     * 计划 id
     */
    @SerializedName("campaign_id")
    private Long campaignId;

    /**
     * 服务商账号 id
     */
    @SerializedName("agency_account_id")
    private Long agencyAccountId;

    /**
     * 微信账号id
     */
    @SerializedName("wechat_account_id")
    private String wechatAccountId;

    /**
     * 微信服务商id
     */
    @SerializedName("wechat_agency_id")
    private String wechatAgencyId;

    /**
     * 广告组 id
     */
    @SerializedName("adgroup_id")
    private Long adgroupId;

    /**
     * 广告 id
     */
    @SerializedName("ad_id")
    private Long adId;

    /**
     * 记录创建时间
     */
    @SerializedName("create_time")
    private Date createTime;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_total")
    private BigDecimal costDeviationRateTotal;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_day")
    private BigDecimal costDeviationRateDay;

    /**
     * 消耗
     */
    @SerializedName("cost_total")
    private Long costTotal;

    /**
     * 消耗
     */
    @SerializedName("cost_day")
    private Long costDay;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_total")
    private Long compensationAmountTotal;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_day")
    private Long compensationAmountDay;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_total")
    private Long viewCountTotal;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_day")
    private Long viewCountDay;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_all")
    private Long thousandDisplayPriceAll;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_day")
    private Long thousandDisplayPriceDay;

    /**
     * 曝光人数。观看广告的独立用户数。
     */
    @SerializedName("view_user_count_total")
    private Long viewUserCountTotal;

    /**
     * 曝光人数。观看广告的独立用户数。
     */
    @SerializedName("view_user_count_day")
    private Long viewUserCountDay;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_all")
    private BigDecimal avgViewPerUserAll;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_day")
    private BigDecimal avgViewPerUserDay;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_total")
    private Long validClickCountTotal;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_day")
    private Long validClickCountDay;

    /**
     * 点击人数。在广告外层进行点击操作的独立用户数。
     */
    @SerializedName("click_user_count_total")
    private Long clickUserCountTotal;

    /**
     * 点击人数。在广告外层进行点击操作的独立用户数。
     */
    @SerializedName("click_user_count_day")
    private Long clickUserCountDay;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_all")
    private BigDecimal ctrAll;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_day")
    private BigDecimal ctrDay;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_all")
    private Long cpcAll;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_day")
    private Long cpcDay;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_total")
    private Long valuableClickCountTotal;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_day")
    private Long valuableClickCountDay;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_all")
    private BigDecimal valuableClickRateAll;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_day")
    private BigDecimal valuableClickRateDay;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_all")
    private Long valuableClickCostAll;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_day")
    private Long valuableClickCostDay;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_total")
    private Long conversionsCountTotal;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_day")
    private Long conversionsCountDay;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_all")
    private Long conversionsCostAll;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_day")
    private Long conversionsCostDay;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_all")
    private BigDecimal conversionsRateAll;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_day")
    private BigDecimal conversionsRateDay;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_total")
    private Long deepConversionsCountTotal;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_day")
    private Long deepConversionsCountDay;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_all")
    private Long deepConversionsCostAll;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_day")
    private Long deepConversionsCostDay;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_all")
    private BigDecimal deepConversionsRateAll;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_day")
    private BigDecimal deepConversionsRateDay;

    /**
     * 关键页面访问人数。点击广告原生落地页的APP跳转按钮，并到达APP内关键页面的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("key_page_uv_total")
    private Long keyPageUvTotal;

    /**
     * 关键页面访问人数。点击广告原生落地页的APP跳转按钮，并到达APP内关键页面的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("key_page_uv_day")
    private Long keyPageUvDay;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_total")
    private Long orderCountTotal;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_day")
    private Long orderCountDay;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_total")
    private Long firstDayOrderCountTotal;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_day")
    private Long firstDayOrderCountDay;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_all")
    private Long webOrderCostAll;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_day")
    private Long webOrderCostDay;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_all")
    private BigDecimal orderRateAll;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_day")
    private BigDecimal orderRateDay;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_total")
    private Long orderAmountTotal;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_day")
    private Long orderAmountDay;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_total")
    private Long firstDayOrderAmountTotal;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_day")
    private Long firstDayOrderAmountDay;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_all")
    private Long orderUnitPriceAll;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_day")
    private Long orderUnitPriceDay;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_all")
    private BigDecimal orderRoiAll;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_day")
    private BigDecimal orderRoiDay;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_total")
    private Long signInCountTotal;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_day")
    private Long signInCountDay;

    /**
     * 加收藏次数。用户将广告主商品加入收藏的次数，接入转化跟踪后可统计。
     */
    @SerializedName("add_wishlist_count_total")
    private Long addWishlistCountTotal;

    /**
     * 加收藏次数。用户将广告主商品加入收藏的次数，接入转化跟踪后可统计。
     */
    @SerializedName("add_wishlist_count_day")
    private Long addWishlistCountDay;

    /**
     * 商品详情页浏览人数。浏览广告主商品详情页的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("view_commodity_page_uv_total")
    private Long viewCommodityPageUvTotal;

    /**
     * 商品详情页浏览人数。浏览广告主商品详情页的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("view_commodity_page_uv_day")
    private Long viewCommodityPageUvDay;

    /**
     * 销售线索次数。广告带来的用户销售线索数量。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("page_reservation_count_total")
    private Long pageReservationCountTotal;

    /**
     * 销售线索次数。广告带来的用户销售线索数量。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("page_reservation_count_day")
    private Long pageReservationCountDay;

    /**
     * 首次付费人数。广告带来的有付费行为的销售线索数量按用户去重，同一个用户多次提交仅计算一次（原付费销售线索人数）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_uv_total")
    private Long leadsPurchaseUvTotal;

    /**
     * 首次付费人数。广告带来的有付费行为的销售线索数量按用户去重，同一个用户多次提交仅计算一次（原付费销售线索人数）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_uv_day")
    private Long leadsPurchaseUvDay;

    /**
     * 首次付费成本（人数）。产生一个首次付费用户的成本（原付费销售线索成本）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_cost_all")
    private Long leadsPurchaseCostAll;

    /**
     * 首次付费成本（人数）。产生一个首次付费用户的成本（原付费销售线索成本）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_cost_day")
    private Long leadsPurchaseCostDay;

    /**
     * 首次付费转化率（人数）。一次点击到产生一个首次付费用户的转化率（原付费销售线索转化率）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_rate_all")
    private BigDecimal leadsPurchaseRateAll;

    /**
     * 首次付费转化率（人数）。一次点击到产生一个首次付费用户的转化率（原付费销售线索转化率）。H5推广需接入转化跟踪后可统计。
     */
    @SerializedName("leads_purchase_rate_day")
    private BigDecimal leadsPurchaseRateDay;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_total")
    private Long scanFollowCountTotal;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_day")
    private Long scanFollowCountDay;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_total")
    private Long wechatAppRegisterUvTotal;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_day")
    private Long wechatAppRegisterUvDay;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_all")
    private Long wechatMinigameRegisterCostAll;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_day")
    private Long wechatMinigameRegisterCostDay;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_all")
    private BigDecimal wechatMinigameRegisterRateAll;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_day")
    private BigDecimal wechatMinigameRegisterRateDay;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_all")
    private BigDecimal wechatMinigameArpuAll;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_day")
    private BigDecimal wechatMinigameArpuDay;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_total")
    private Long wechatMinigameRetentionCountTotal;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_day")
    private Long wechatMinigameRetentionCountDay;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_total")
    private Long wechatMinigameCheckoutCountTotal;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_day")
    private Long wechatMinigameCheckoutCountDay;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_total")
    private Long wechatMinigameCheckoutAmountTotal;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_day")
    private Long wechatMinigameCheckoutAmountDay;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_total")
    private Long officialAccountFollowCountTotal;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_day")
    private Long officialAccountFollowCountDay;

    /**
     * 公众号关注成本（次数）。产生一次公众号关注的成本。
     */
    @SerializedName("official_account_follow_cost_all")
    private Long officialAccountFollowCostAll;

    /**
     * 公众号关注成本（次数）。产生一次公众号关注的成本。
     */
    @SerializedName("official_account_follow_cost_day")
    private Long officialAccountFollowCostDay;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_all")
    private BigDecimal officialAccountFollowRateAll;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_day")
    private BigDecimal officialAccountFollowRateDay;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_total")
    private Long officialAccountRegisterUserCountTotal;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_day")
    private Long officialAccountRegisterUserCountDay;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_all")
    private BigDecimal officialAccountRegisterRateAll;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_day")
    private BigDecimal officialAccountRegisterRateDay;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_all")
    private Long officialAccountRegisterCostAll;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_day")
    private Long officialAccountRegisterCostDay;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_total")
    private Long officialAccountRegisterAmountTotal;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_day")
    private Long officialAccountRegisterAmountDay;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_all")
    private Long officialAccountRegisterRoiAll;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_day")
    private Long officialAccountRegisterRoiDay;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_total")
    private Long officialAccountApplyCountTotal;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_day")
    private Long officialAccountApplyCountDay;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_total")
    private Long officialAccountApplyUserCountTotal;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_day")
    private Long officialAccountApplyUserCountDay;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_all")
    private BigDecimal officialAccountApplyRateAll;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_day")
    private BigDecimal officialAccountApplyRateDay;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_all")
    private Long officialAccountApplyCostAll;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_day")
    private Long officialAccountApplyCostDay;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_total")
    private Long officialAccountApplyAmountTotal;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_day")
    private Long officialAccountApplyAmountDay;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_all")
    private Long officialAccountApplyRoiAll;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_day")
    private Long officialAccountApplyRoiDay;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_total")
    private Long officialAccountOrderCountTotal;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_day")
    private Long officialAccountOrderCountDay;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_total")
    private Long officialAccountFirstDayOrderCountTotal;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_day")
    private Long officialAccountFirstDayOrderCountDay;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_total")
    private Long officialAccountOrderUserCountTotal;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_day")
    private Long officialAccountOrderUserCountDay;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_all")
    private BigDecimal officialAccountOrderRateAll;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_day")
    private BigDecimal officialAccountOrderRateDay;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_all")
    private Long officialAccountOrderCostAll;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_day")
    private Long officialAccountOrderCostDay;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_total")
    private Long officialAccountOrderAmountTotal;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_day")
    private Long officialAccountOrderAmountDay;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_total")
    private Long officialAccountFirstDayOrderAmountTotal;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_day")
    private Long officialAccountFirstDayOrderAmountDay;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_all")
    private Long officialAccountOrderRoiAll;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_day")
    private Long officialAccountOrderRoiDay;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_total")
    private Long officialAccountConsultCountTotal;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_day")
    private Long officialAccountConsultCountDay;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_total")
    private Long officialAccountReaderCountTotal;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_day")
    private Long officialAccountReaderCountDay;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_total")
    private Long officialAccountCreditApplyUserCountTotal;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_day")
    private Long officialAccountCreditApplyUserCountDay;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_total")
    private Long officialAccountCreditUserCountTotal;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_day")
    private Long officialAccountCreditUserCountDay;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_total")
    private Long forwardCountTotal;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_day")
    private Long forwardCountDay;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_total")
    private Long forwardUserCountTotal;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_day")
    private Long forwardUserCountDay;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_total")
    private Long noInterestCountTotal;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_day")
    private Long noInterestCountDay;

    /**
     * 聚合
     *
     * @param lastDayDWD 之前聚合的值（可能为 null）
     * @param dayODS     新值
     * @param createTime 聚合时间
     * @return
     */
    public static AdStatOfDayDWD reduce(AdStatOfDayDWD lastDayDWD, AdDataOfDayODS dayODS, long createTime) {
        AdStatOfDayDWD result = new AdStatOfDayDWD();
        BeanUtils.copyProperties(dayODS, result);
        result.setCreateTime(new Date(createTime));
        if (lastDayDWD == null) {
            result.setCostDeviationRateTotal(dayODS.getCostDeviationRate());
            result.setCostDeviationRateDay(dayODS.getCostDeviationRate());
            result.setCostTotal(dayODS.getCost());
            result.setCostDay(dayODS.getCost());
            result.setCompensationAmountTotal(dayODS.getCompensationAmount());
            result.setCompensationAmountDay(dayODS.getCompensationAmount());
            result.setViewCountTotal(dayODS.getViewCount());
            result.setViewCountDay(dayODS.getViewCount());
            result.setViewUserCountTotal(dayODS.getViewUserCount());
            result.setViewUserCountDay(dayODS.getViewUserCount());
            result.setValidClickCountTotal(dayODS.getValidClickCount());
            result.setValidClickCountDay(dayODS.getValidClickCount());
            result.setClickUserCountTotal(dayODS.getClickUserCount());
            result.setClickUserCountDay(dayODS.getClickUserCount());
            result.setValuableClickCountTotal(dayODS.getValuableClickCount());
            result.setValuableClickCountDay(dayODS.getValuableClickCount());
            result.setConversionsCountTotal(dayODS.getConversionsCount());
            result.setConversionsCountDay(dayODS.getConversionsCount());
            result.setDeepConversionsCountTotal(dayODS.getDeepConversionsCount());
            result.setDeepConversionsCountDay(dayODS.getDeepConversionsCount());
            result.setKeyPageUvTotal(dayODS.getKeyPageUv());
            result.setKeyPageUvDay(dayODS.getKeyPageUv());
            result.setOrderCountTotal(dayODS.getOrderCount());
            result.setOrderCountDay(dayODS.getOrderCount());
            result.setFirstDayOrderCountTotal(dayODS.getFirstDayOrderCount());
            result.setFirstDayOrderCountDay(dayODS.getFirstDayOrderCount());
            result.setOrderAmountTotal(dayODS.getOrderAmount());
            result.setOrderAmountDay(dayODS.getOrderAmount());
            result.setFirstDayOrderAmountTotal(dayODS.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountDay(dayODS.getFirstDayOrderAmount());
            result.setSignInCountTotal(dayODS.getSignInCount());
            result.setSignInCountDay(dayODS.getSignInCount());
            result.setAddWishlistCountTotal(dayODS.getAddWishlistCount());
            result.setAddWishlistCountDay(dayODS.getAddWishlistCount());
            result.setViewCommodityPageUvTotal(dayODS.getViewCommodityPageUv());
            result.setViewCommodityPageUvDay(dayODS.getViewCommodityPageUv());
            result.setPageReservationCountTotal(dayODS.getPageReservationCount());
            result.setPageReservationCountDay(dayODS.getPageReservationCount());
            result.setLeadsPurchaseUvTotal(dayODS.getLeadsPurchaseUv());
            result.setLeadsPurchaseUvDay(dayODS.getLeadsPurchaseUv());
            result.setScanFollowCountTotal(dayODS.getScanFollowCount());
            result.setScanFollowCountDay(dayODS.getScanFollowCount());
            result.setWechatAppRegisterUvTotal(dayODS.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvDay(dayODS.getWechatAppRegisterUv());
            result.setWechatMinigameRetentionCountTotal(dayODS.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountDay(dayODS.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountTotal(dayODS.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountDay(dayODS.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountTotal(dayODS.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountDay(dayODS.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountTotal(dayODS.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountDay(dayODS.getOfficialAccountFollowCount());
            result.setOfficialAccountRegisterUserCountTotal(dayODS.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountDay(dayODS.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterAmountTotal(dayODS.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountDay(dayODS.getOfficialAccountRegisterAmount());
            result.setOfficialAccountApplyCountTotal(dayODS.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountDay(dayODS.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountTotal(dayODS.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountDay(dayODS.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyAmountTotal(dayODS.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountDay(dayODS.getOfficialAccountApplyAmount());
            result.setOfficialAccountOrderCountTotal(dayODS.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountDay(dayODS.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountTotal(dayODS.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(dayODS.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountTotal(dayODS.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountDay(dayODS.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderAmountTotal(dayODS.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountDay(dayODS.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountTotal(dayODS.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(dayODS.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountConsultCountTotal(dayODS.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountDay(dayODS.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountTotal(dayODS.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountDay(dayODS.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountTotal(dayODS.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountDay(dayODS.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountTotal(dayODS.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountDay(dayODS.getOfficialAccountCreditUserCount());
            result.setForwardCountTotal(dayODS.getForwardCount());
            result.setForwardCountDay(dayODS.getForwardCount());
            result.setForwardUserCountTotal(dayODS.getForwardUserCount());
            result.setForwardUserCountDay(dayODS.getForwardUserCount());
            result.setNoInterestCountTotal(dayODS.getNoInterestCount());
            result.setNoInterestCountDay(dayODS.getNoInterestCount());
        } else {
            result.setCostDeviationRateTotal(lastDayDWD.getCostDeviationRateTotal().add(dayODS.getCostDeviationRate()));
            result.setCostDeviationRateDay(dayODS.getCostDeviationRate());
            result.setCostTotal(lastDayDWD.getCostTotal() + dayODS.getCost());
            result.setCostDay(dayODS.getCost());
            result.setCompensationAmountTotal(lastDayDWD.getCompensationAmountTotal() + dayODS.getCompensationAmount());
            result.setCompensationAmountDay(dayODS.getCompensationAmount());
            result.setViewCountTotal(lastDayDWD.getViewCountTotal() + dayODS.getViewCount());
            result.setViewCountDay(dayODS.getViewCount());

            // 应该不准，因为跨天的用户无法去重
            result.setViewUserCountTotal(lastDayDWD.getViewUserCountTotal() + dayODS.getViewUserCount());
            result.setViewUserCountDay(dayODS.getViewUserCount());
            result.setValidClickCountTotal(lastDayDWD.getValidClickCountTotal() + dayODS.getValidClickCount());
            result.setValidClickCountDay(dayODS.getValidClickCount());

            // 应该不准，因为跨天的用户无法去重
            result.setClickUserCountTotal(lastDayDWD.getClickUserCountTotal() + dayODS.getClickUserCount());
            result.setClickUserCountDay(dayODS.getClickUserCount());
            result.setCtrDay(dayODS.getCtr());
            result.setCpcDay(dayODS.getCpc());
            result.setValuableClickCountTotal(lastDayDWD.getValuableClickCountTotal() + dayODS.getValuableClickCount());
            result.setValuableClickCountDay(dayODS.getValuableClickCount());
            result.setConversionsCountTotal(lastDayDWD.getConversionsCountTotal() + dayODS.getConversionsCount());
            result.setConversionsCountDay(dayODS.getConversionsCount());
            result.setDeepConversionsCountTotal(lastDayDWD.getDeepConversionsCountTotal() + dayODS.getDeepConversionsCount());
            result.setDeepConversionsCountDay(dayODS.getDeepConversionsCount());
            result.setKeyPageUvTotal(lastDayDWD.getKeyPageUvTotal() + dayODS.getKeyPageUv());
            result.setKeyPageUvDay(dayODS.getKeyPageUv());
            result.setOrderCountTotal(lastDayDWD.getOrderCountTotal() + dayODS.getOrderCount());
            result.setOrderCountDay(dayODS.getOrderCount());
            result.setFirstDayOrderCountTotal(lastDayDWD.getFirstDayOrderCountTotal() + dayODS.getFirstDayOrderCount());
            result.setFirstDayOrderCountDay(dayODS.getFirstDayOrderCount());
            result.setOrderAmountTotal(lastDayDWD.getOrderAmountTotal() + dayODS.getOrderAmount());
            result.setOrderAmountDay(dayODS.getOrderAmount());
            result.setFirstDayOrderAmountTotal(lastDayDWD.getFirstDayOrderAmountTotal() + dayODS.getFirstDayOrderAmount());
            result.setFirstDayOrderAmountDay(dayODS.getFirstDayOrderAmount());
            result.setSignInCountTotal(lastDayDWD.getSignInCountTotal() + dayODS.getSignInCount());
            result.setSignInCountDay(dayODS.getSignInCount());
            result.setAddWishlistCountTotal(lastDayDWD.getAddWishlistCountTotal() + dayODS.getAddWishlistCount());
            result.setAddWishlistCountDay(dayODS.getAddWishlistCount());
            result.setViewCommodityPageUvTotal(lastDayDWD.getViewCommodityPageUvTotal() + dayODS.getViewCommodityPageUv());
            result.setViewCommodityPageUvDay(dayODS.getViewCommodityPageUv());
            result.setPageReservationCountTotal(lastDayDWD.getPageReservationCountTotal() + dayODS.getPageReservationCount());
            result.setPageReservationCountDay(dayODS.getPageReservationCount());

            // 应该不准，因为跨天的用户无法去重
            result.setLeadsPurchaseUvTotal(lastDayDWD.getLeadsPurchaseUvTotal() + dayODS.getLeadsPurchaseUv());
            result.setLeadsPurchaseUvDay(dayODS.getLeadsPurchaseUv());
            result.setScanFollowCountTotal(lastDayDWD.getScanFollowCountTotal() + dayODS.getScanFollowCount());
            result.setScanFollowCountDay(dayODS.getScanFollowCount());
            result.setWechatAppRegisterUvTotal(lastDayDWD.getWechatAppRegisterUvTotal() + dayODS.getWechatAppRegisterUv());
            result.setWechatAppRegisterUvDay(dayODS.getWechatAppRegisterUv());
            result.setWechatMinigameRetentionCountTotal(lastDayDWD.getWechatMinigameRetentionCountTotal() + dayODS.getWechatMinigameRetentionCount());
            result.setWechatMinigameRetentionCountDay(dayODS.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountTotal(lastDayDWD.getWechatMinigameCheckoutCountTotal() + dayODS.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutCountDay(dayODS.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountTotal(lastDayDWD.getWechatMinigameCheckoutAmountTotal() + dayODS.getWechatMinigameCheckoutAmount());
            result.setWechatMinigameCheckoutAmountDay(dayODS.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountTotal(lastDayDWD.getOfficialAccountFollowCountTotal() + dayODS.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowCountDay(dayODS.getOfficialAccountFollowCount());
            result.setOfficialAccountRegisterUserCountTotal(lastDayDWD.getOfficialAccountRegisterUserCountTotal() + dayODS.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterUserCountDay(dayODS.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterAmountTotal(lastDayDWD.getOfficialAccountRegisterAmountTotal() + dayODS.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterAmountDay(dayODS.getOfficialAccountRegisterAmount());
            result.setOfficialAccountApplyCountTotal(lastDayDWD.getOfficialAccountApplyCountTotal() + dayODS.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyCountDay(dayODS.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountTotal(lastDayDWD.getOfficialAccountApplyUserCountTotal() + dayODS.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyUserCountDay(dayODS.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyAmountTotal(lastDayDWD.getOfficialAccountApplyAmountTotal() + dayODS.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyAmountDay(dayODS.getOfficialAccountApplyAmount());
            result.setOfficialAccountOrderCountTotal(lastDayDWD.getOfficialAccountOrderCountTotal() + dayODS.getOfficialAccountOrderCount());
            result.setOfficialAccountOrderCountDay(dayODS.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountTotal(lastDayDWD.getOfficialAccountFirstDayOrderCountTotal() + dayODS.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(dayODS.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountTotal(lastDayDWD.getOfficialAccountOrderUserCountTotal() + dayODS.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderUserCountDay(dayODS.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderAmountTotal(lastDayDWD.getOfficialAccountOrderAmountTotal() + dayODS.getOfficialAccountOrderAmount());
            result.setOfficialAccountOrderAmountDay(dayODS.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountTotal(lastDayDWD.getOfficialAccountFirstDayOrderAmountTotal() + dayODS.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(dayODS.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountConsultCountTotal(lastDayDWD.getOfficialAccountConsultCountTotal() + dayODS.getOfficialAccountConsultCount());
            result.setOfficialAccountConsultCountDay(dayODS.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountTotal(lastDayDWD.getOfficialAccountReaderCountTotal() + dayODS.getOfficialAccountReaderCount());
            result.setOfficialAccountReaderCountDay(dayODS.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountTotal(lastDayDWD.getOfficialAccountCreditApplyUserCountTotal() + dayODS.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditApplyUserCountDay(dayODS.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountTotal(lastDayDWD.getOfficialAccountCreditUserCountTotal() + dayODS.getOfficialAccountCreditUserCount());
            result.setOfficialAccountCreditUserCountDay(dayODS.getOfficialAccountCreditUserCount());
            result.setForwardCountTotal(lastDayDWD.getForwardCountTotal() + dayODS.getForwardCount());
            result.setForwardCountDay(dayODS.getForwardCount());
            result.setForwardUserCountTotal(lastDayDWD.getForwardUserCountTotal() + dayODS.getForwardUserCount());
            result.setForwardUserCountDay(dayODS.getForwardUserCount());
            result.setNoInterestCountTotal(lastDayDWD.getNoInterestCountTotal() + dayODS.getNoInterestCount());
            result.setNoInterestCountDay(dayODS.getNoInterestCount());
        }
        // 曝光次数 / 曝光人数
        result.setAvgViewPerUserAll(NumberUtil.divideForAd(result.getViewCountTotal(), result.getViewUserCountTotal()));
        result.setAvgViewPerUserDay(NumberUtil.divideForAd(result.getViewCountDay(), result.getViewUserCountDay()));
        // 总消耗 / 总曝光
        result.setThousandDisplayPriceAll(NumberUtil.divideForAd(result.getCostTotal(), result.getViewCountTotal()).multiply(new BigDecimal(1000)).longValue());
        result.setThousandDisplayPriceDay(NumberUtil.divideForAd(result.getCostDay(), result.getViewCountDay()).multiply(new BigDecimal(1000)).longValue());
        // 广告点击次数 / 广告曝光次数
        result.setCtrAll(NumberUtil.divideForAd(result.getValidClickCountTotal(), result.getViewCountTotal()));
        result.setCtrDay(NumberUtil.divideForAd(result.getValidClickCountDay(), result.getViewCountDay()));
        // 广告花费/广告点击次数
        result.setCpcAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getValidClickCountTotal()));
        result.setCpcDay(NumberUtil.divideForMoney(result.getCostDay(), result.getValidClickCountDay()));
        // 广告可转化点击次数/广告曝光次数
        result.setValuableClickRateAll(NumberUtil.divideForAd(result.getValuableClickCountTotal(), result.getViewCountTotal()));
        result.setValuableClickRateDay(NumberUtil.divideForAd(result.getValuableClickCountDay(), result.getViewCountDay()));
        // 广告花费/可转化点击次数
        result.setValuableClickCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getValuableClickCountTotal()));
        result.setValuableClickCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getValuableClickCountDay()));
        // 广告花费/转化目标量
        result.setConversionsCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getConversionsCountTotal()));
        result.setConversionsCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getConversionsCountDay()));
        // 公众号：转化目标量/点击次数。
        result.setConversionsRateAll(NumberUtil.divideForAd(result.getConversionsCountTotal(), result.getValidClickCountTotal()));
        result.setConversionsRateDay(NumberUtil.divideForAd(result.getConversionsCountDay(), result.getValidClickCountDay()));
        // 广告花费/深度转化目标量
        result.setDeepConversionsCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getDeepConversionsCountTotal()));
        result.setDeepConversionsCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getDeepConversionsCountDay()));
        // 深度转化目标量/可转化点击次数
        result.setDeepConversionsRateAll(NumberUtil.divideForAd(result.getDeepConversionsCountTotal(), result.getValuableClickCountTotal()));
        result.setDeepConversionsRateDay(NumberUtil.divideForAd(result.getDeepConversionsCountDay(), result.getValuableClickCountDay()));
        // 广告花费/下单量
        result.setWebOrderCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getOrderCountTotal()));
        result.setWebOrderCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getOrderCountDay()));
        // 下单量/点击次数
        result.setOrderRateAll(NumberUtil.divideForAd(result.getOrderCountTotal(), result.getValidClickCountTotal()));
        result.setOrderRateDay(NumberUtil.divideForAd(result.getOrderCountDay(), result.getValidClickCountDay()));
        // 下单金额/下单量
        result.setOrderUnitPriceAll(NumberUtil.divideForMoney(result.getOrderAmountTotal(), result.getOrderCountTotal()));
        result.setOrderUnitPriceDay(NumberUtil.divideForMoney(result.getOrderAmountDay(), result.getOrderCountDay()));
        // 下单金额/广告花费
        result.setOrderRoiAll(NumberUtil.divideForAd(result.getOrderAmountTotal(), result.getCostTotal()));
        result.setOrderRoiDay(NumberUtil.divideForAd(result.getOrderAmountDay(), result.getCostDay()));
        // 广告消耗/首次付费人数
        result.setLeadsPurchaseCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getLeadsPurchaseUvTotal()));
        result.setLeadsPurchaseCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getLeadsPurchaseUvDay()));
        // 首次付费人数/广告点击次数
        result.setLeadsPurchaseRateAll(NumberUtil.divideForAd(result.getLeadsPurchaseUvTotal(), result.getValidClickCountTotal()));
        result.setLeadsPurchaseRateDay(NumberUtil.divideForAd(result.getLeadsPurchaseUvDay(), result.getValidClickCountDay()));
        // 广告消耗 / 小游戏注册人数
        result.setWechatMinigameRegisterCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getWechatAppRegisterUvTotal()));
        result.setWechatMinigameRegisterCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getWechatAppRegisterUvDay()));
        // 小游戏注册人数 / 广告点击次数
        result.setWechatMinigameRegisterRateAll(NumberUtil.divideForAd(result.getWechatAppRegisterUvTotal(), result.getValidClickCountTotal()));
        result.setWechatMinigameRegisterRateDay(NumberUtil.divideForAd(result.getWechatAppRegisterUvDay(), result.getValidClickCountDay()));
        // 总收益 / 总人数
        result.setWechatMinigameArpuAll(NumberUtil.divideForAd(result.getOrderAmountTotal(), result.getWechatAppRegisterUvTotal()));
        result.setWechatMinigameArpuDay(NumberUtil.divideForAd(result.getOrderAmountDay(), result.getWechatAppRegisterUvDay()));
        // 广告消耗 / 关注次数
        result.setOfficialAccountFollowCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountFollowCountTotal()));
        result.setOfficialAccountFollowCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountFollowCountDay()));
        // 关注次数 / 点击次数
        result.setOfficialAccountFollowRateAll(NumberUtil.divideForAd(result.getOfficialAccountFollowCountTotal(), result.getValidClickCountTotal()));
        result.setOfficialAccountFollowRateDay(NumberUtil.divideForAd(result.getOfficialAccountFollowCountDay(), result.getValidClickCountDay()));
        // 公众号内注册人数 / 公众号关注次数
        result.setOfficialAccountRegisterRateAll(NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
        result.setOfficialAccountRegisterRateDay(NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountDay(), result.getOfficialAccountFollowCountDay()));
        // 广告消耗 / 广告注册人数
        result.setOfficialAccountRegisterCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountRegisterUserCountTotal()));
        result.setOfficialAccountRegisterCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountRegisterUserCountDay()));
        // 注册产生的订单金额累计/广告花费
        result.setOfficialAccountRegisterRoiAll(NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountTotal(), result.getCostTotal()));
        result.setOfficialAccountRegisterRoiDay(NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountDay(), result.getCostDay()));
        // 公众号内填单的独立用户数/公众号关注次数
        result.setOfficialAccountApplyRateAll(NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
        result.setOfficialAccountApplyRateDay(NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountDay(), result.getOfficialAccountFollowCountDay()));
        // 广告花费/广告产生的填单行为数量
        result.setOfficialAccountApplyCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountApplyUserCountTotal()));
        result.setOfficialAccountApplyCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountApplyUserCountDay()));
        // 填单产生的订单金额累计/广告花费
        result.setOfficialAccountApplyRoiAll(NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountTotal(), result.getCostTotal()));
        result.setOfficialAccountApplyRoiDay(NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountDay(), result.getCostDay()));
        // 公众号内下单独立用户数（UV）/公众号关注次数
        result.setOfficialAccountOrderRateAll(NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
        result.setOfficialAccountOrderRateDay(NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountDay(), result.getOfficialAccountFollowCountDay()));
        // 广告花费/广告产生的下单行为数量
        result.setOfficialAccountOrderCostAll(NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountOrderCountTotal()));
        result.setOfficialAccountOrderCostDay(NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountOrderCountDay()));
        // 下单产生的订单金额累计/广告花费
        result.setOfficialAccountOrderRoiAll(NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountTotal(), result.getCostTotal()));
        result.setOfficialAccountOrderRoiDay(NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountDay(), result.getCostDay()));
        return result;
    }

    public static AdStatOfDayDWD byMaxCompute(Record record) {
        AdStatOfDayDWD result = new AdStatOfDayDWD();
        result.setStatDay(ObjectUtil.toString(record.get("stat_day")));
        result.setAccountId(ObjectUtil.toLong(record.get("account_id")));
        result.setCampaignId(ObjectUtil.toLong(record.get("campaign_id")));
        result.setAgencyAccountId(ObjectUtil.toLong(record.get("agency_account_id")));
        result.setWechatAccountId(ObjectUtil.toString(record.get("wechat_account_id")));
        result.setWechatAgencyId(ObjectUtil.toString(record.get("wechat_agency_id")));
        result.setAdgroupId(ObjectUtil.toLong(record.get("adgroup_id")));
        result.setAdId(ObjectUtil.toLong(record.get("ad_id")));
        result.setCreateTime(ObjectUtil.toDate(record.get("create_time")));
        result.setCostDeviationRateTotal(ObjectUtil.toDecimal(record.get("cost_deviation_rate_total")));
        result.setCostDeviationRateDay(ObjectUtil.toDecimal(record.get("cost_deviation_rate_day")));
        result.setCostTotal(ObjectUtil.toLong(record.get("cost_total")));
        result.setCostDay(ObjectUtil.toLong(record.get("cost_day")));
        result.setCompensationAmountTotal(ObjectUtil.toLong(record.get("compensation_amount_total")));
        result.setCompensationAmountDay(ObjectUtil.toLong(record.get("compensation_amount_day")));
        result.setViewCountTotal(ObjectUtil.toLong(record.get("view_count_total")));
        result.setViewCountDay(ObjectUtil.toLong(record.get("view_count_day")));
        result.setThousandDisplayPriceAll(ObjectUtil.toLong(record.get("thousand_display_price_all")));
        result.setThousandDisplayPriceDay(ObjectUtil.toLong(record.get("thousand_display_price_day")));
        result.setViewUserCountTotal(ObjectUtil.toLong(record.get("view_user_count_total")));
        result.setViewUserCountDay(ObjectUtil.toLong(record.get("view_user_count_day")));
        result.setAvgViewPerUserAll(ObjectUtil.toDecimal(record.get("avg_view_per_user_all")));
        result.setAvgViewPerUserDay(ObjectUtil.toDecimal(record.get("avg_view_per_user_day")));
        result.setValidClickCountTotal(ObjectUtil.toLong(record.get("valid_click_count_total")));
        result.setValidClickCountDay(ObjectUtil.toLong(record.get("valid_click_count_day")));
        result.setClickUserCountTotal(ObjectUtil.toLong(record.get("click_user_count_total")));
        result.setClickUserCountDay(ObjectUtil.toLong(record.get("click_user_count_day")));
        result.setCtrAll(ObjectUtil.toDecimal(record.get("ctr_all")));
        result.setCtrDay(ObjectUtil.toDecimal(record.get("ctr_day")));
        result.setCpcAll(ObjectUtil.toLong(record.get("cpc_all")));
        result.setCpcDay(ObjectUtil.toLong(record.get("cpc_day")));
        result.setValuableClickCountTotal(ObjectUtil.toLong(record.get("valuable_click_count_total")));
        result.setValuableClickCountDay(ObjectUtil.toLong(record.get("valuable_click_count_day")));
        result.setValuableClickRateAll(ObjectUtil.toDecimal(record.get("valuable_click_rate_all")));
        result.setValuableClickRateDay(ObjectUtil.toDecimal(record.get("valuable_click_rate_day")));
        result.setValuableClickCostAll(ObjectUtil.toLong(record.get("valuable_click_cost_all")));
        result.setValuableClickCostDay(ObjectUtil.toLong(record.get("valuable_click_cost_day")));
        result.setConversionsCountTotal(ObjectUtil.toLong(record.get("conversions_count_total")));
        result.setConversionsCountDay(ObjectUtil.toLong(record.get("conversions_count_day")));
        result.setConversionsCostAll(ObjectUtil.toLong(record.get("conversions_cost_all")));
        result.setConversionsCostDay(ObjectUtil.toLong(record.get("conversions_cost_day")));
        result.setConversionsRateAll(ObjectUtil.toDecimal(record.get("conversions_rate_all")));
        result.setConversionsRateDay(ObjectUtil.toDecimal(record.get("conversions_rate_day")));
        result.setDeepConversionsCountTotal(ObjectUtil.toLong(record.get("deep_conversions_count_total")));
        result.setDeepConversionsCountDay(ObjectUtil.toLong(record.get("deep_conversions_count_day")));
        result.setDeepConversionsCostAll(ObjectUtil.toLong(record.get("deep_conversions_cost_all")));
        result.setDeepConversionsCostDay(ObjectUtil.toLong(record.get("deep_conversions_cost_day")));
        result.setDeepConversionsRateAll(ObjectUtil.toDecimal(record.get("deep_conversions_rate_all")));
        result.setDeepConversionsRateDay(ObjectUtil.toDecimal(record.get("deep_conversions_rate_day")));
        result.setKeyPageUvTotal(ObjectUtil.toLong(record.get("key_page_uv_total")));
        result.setKeyPageUvDay(ObjectUtil.toLong(record.get("key_page_uv_day")));
        result.setOrderCountTotal(ObjectUtil.toLong(record.get("order_count_total")));
        result.setOrderCountDay(ObjectUtil.toLong(record.get("order_count_day")));
        result.setFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("first_day_order_count_total")));
        result.setFirstDayOrderCountDay(ObjectUtil.toLong(record.get("first_day_order_count_day")));
        result.setWebOrderCostAll(ObjectUtil.toLong(record.get("web_order_cost_all")));
        result.setWebOrderCostDay(ObjectUtil.toLong(record.get("web_order_cost_day")));
        result.setOrderRateAll(ObjectUtil.toDecimal(record.get("order_rate_all")));
        result.setOrderRateDay(ObjectUtil.toDecimal(record.get("order_rate_day")));
        result.setOrderAmountTotal(ObjectUtil.toLong(record.get("order_amount_total")));
        result.setOrderAmountDay(ObjectUtil.toLong(record.get("order_amount_day")));
        result.setFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("first_day_order_amount_total")));
        result.setFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("first_day_order_amount_day")));
        result.setOrderUnitPriceAll(ObjectUtil.toLong(record.get("order_unit_price_all")));
        result.setOrderUnitPriceDay(ObjectUtil.toLong(record.get("order_unit_price_day")));
        result.setOrderRoiAll(ObjectUtil.toDecimal(record.get("order_roi_all")));
        result.setOrderRoiDay(ObjectUtil.toDecimal(record.get("order_roi_day")));
        result.setSignInCountTotal(ObjectUtil.toLong(record.get("sign_in_count_total")));
        result.setSignInCountDay(ObjectUtil.toLong(record.get("sign_in_count_day")));
        result.setAddWishlistCountTotal(ObjectUtil.toLong(record.get("add_wishlist_count_total")));
        result.setAddWishlistCountDay(ObjectUtil.toLong(record.get("add_wishlist_count_day")));
        result.setViewCommodityPageUvTotal(ObjectUtil.toLong(record.get("view_commodity_page_uv_total")));
        result.setViewCommodityPageUvDay(ObjectUtil.toLong(record.get("view_commodity_page_uv_day")));
        result.setPageReservationCountTotal(ObjectUtil.toLong(record.get("page_reservation_count_total")));
        result.setPageReservationCountDay(ObjectUtil.toLong(record.get("page_reservation_count_day")));
        result.setLeadsPurchaseUvTotal(ObjectUtil.toLong(record.get("leads_purchase_uv_total")));
        result.setLeadsPurchaseUvDay(ObjectUtil.toLong(record.get("leads_purchase_uv_day")));
        result.setLeadsPurchaseCostAll(ObjectUtil.toLong(record.get("leads_purchase_cost_all")));
        result.setLeadsPurchaseCostDay(ObjectUtil.toLong(record.get("leads_purchase_cost_day")));
        result.setLeadsPurchaseRateAll(ObjectUtil.toDecimal(record.get("leads_purchase_rate_all")));
        result.setLeadsPurchaseRateDay(ObjectUtil.toDecimal(record.get("leads_purchase_rate_day")));
        result.setScanFollowCountTotal(ObjectUtil.toLong(record.get("scan_follow_count_total")));
        result.setScanFollowCountDay(ObjectUtil.toLong(record.get("scan_follow_count_day")));
        result.setWechatAppRegisterUvTotal(ObjectUtil.toLong(record.get("wechat_app_register_uv_total")));
        result.setWechatAppRegisterUvDay(ObjectUtil.toLong(record.get("wechat_app_register_uv_day")));
        result.setWechatMinigameRegisterCostAll(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_all")));
        result.setWechatMinigameRegisterCostDay(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_day")));
        result.setWechatMinigameRegisterRateAll(ObjectUtil.toDecimal(record.get("wechat_minigame_register_rate_all")));
        result.setWechatMinigameRegisterRateDay(ObjectUtil.toDecimal(record.get("wechat_minigame_register_rate_day")));
        result.setWechatMinigameArpuAll(ObjectUtil.toDecimal(record.get("wechat_minigame_arpu_all")));
        result.setWechatMinigameArpuDay(ObjectUtil.toDecimal(record.get("wechat_minigame_arpu_day")));
        result.setWechatMinigameRetentionCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_total")));
        result.setWechatMinigameRetentionCountDay(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_day")));
        result.setWechatMinigameCheckoutCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_total")));
        result.setWechatMinigameCheckoutCountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_day")));
        result.setWechatMinigameCheckoutAmountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_total")));
        result.setWechatMinigameCheckoutAmountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_day")));
        result.setOfficialAccountFollowCountTotal(ObjectUtil.toLong(record.get("official_account_follow_count_total")));
        result.setOfficialAccountFollowCountDay(ObjectUtil.toLong(record.get("official_account_follow_count_day")));
        result.setOfficialAccountFollowCostAll(ObjectUtil.toLong(record.get("official_account_follow_cost_all")));
        result.setOfficialAccountFollowCostDay(ObjectUtil.toLong(record.get("official_account_follow_cost_day")));
        result.setOfficialAccountFollowRateAll(ObjectUtil.toDecimal(record.get("official_account_follow_rate_all")));
        result.setOfficialAccountFollowRateDay(ObjectUtil.toDecimal(record.get("official_account_follow_rate_day")));
        result.setOfficialAccountRegisterUserCountTotal(ObjectUtil.toLong(record.get("official_account_register_user_count_total")));
        result.setOfficialAccountRegisterUserCountDay(ObjectUtil.toLong(record.get("official_account_register_user_count_day")));
        result.setOfficialAccountRegisterRateAll(ObjectUtil.toDecimal(record.get("official_account_register_rate_all")));
        result.setOfficialAccountRegisterRateDay(ObjectUtil.toDecimal(record.get("official_account_register_rate_day")));
        result.setOfficialAccountRegisterCostAll(ObjectUtil.toLong(record.get("official_account_register_cost_all")));
        result.setOfficialAccountRegisterCostDay(ObjectUtil.toLong(record.get("official_account_register_cost_day")));
        result.setOfficialAccountRegisterAmountTotal(ObjectUtil.toLong(record.get("official_account_register_amount_total")));
        result.setOfficialAccountRegisterAmountDay(ObjectUtil.toLong(record.get("official_account_register_amount_day")));
        result.setOfficialAccountRegisterRoiAll(ObjectUtil.toLong(record.get("official_account_register_roi_all")));
        result.setOfficialAccountRegisterRoiDay(ObjectUtil.toLong(record.get("official_account_register_roi_day")));
        result.setOfficialAccountApplyCountTotal(ObjectUtil.toLong(record.get("official_account_apply_count_total")));
        result.setOfficialAccountApplyCountDay(ObjectUtil.toLong(record.get("official_account_apply_count_day")));
        result.setOfficialAccountApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_apply_user_count_total")));
        result.setOfficialAccountApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_apply_user_count_day")));
        result.setOfficialAccountApplyRateAll(ObjectUtil.toDecimal(record.get("official_account_apply_rate_all")));
        result.setOfficialAccountApplyRateDay(ObjectUtil.toDecimal(record.get("official_account_apply_rate_day")));
        result.setOfficialAccountApplyCostAll(ObjectUtil.toLong(record.get("official_account_apply_cost_all")));
        result.setOfficialAccountApplyCostDay(ObjectUtil.toLong(record.get("official_account_apply_cost_day")));
        result.setOfficialAccountApplyAmountTotal(ObjectUtil.toLong(record.get("official_account_apply_amount_total")));
        result.setOfficialAccountApplyAmountDay(ObjectUtil.toLong(record.get("official_account_apply_amount_day")));
        result.setOfficialAccountApplyRoiAll(ObjectUtil.toLong(record.get("official_account_apply_roi_all")));
        result.setOfficialAccountApplyRoiDay(ObjectUtil.toLong(record.get("official_account_apply_roi_day")));
        result.setOfficialAccountOrderCountTotal(ObjectUtil.toLong(record.get("official_account_order_count_total")));
        result.setOfficialAccountOrderCountDay(ObjectUtil.toLong(record.get("official_account_order_count_day")));
        result.setOfficialAccountFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_count_total")));
        result.setOfficialAccountFirstDayOrderCountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_count_day")));
        result.setOfficialAccountOrderUserCountTotal(ObjectUtil.toLong(record.get("official_account_order_user_count_total")));
        result.setOfficialAccountOrderUserCountDay(ObjectUtil.toLong(record.get("official_account_order_user_count_day")));
        result.setOfficialAccountOrderRateAll(ObjectUtil.toDecimal(record.get("official_account_order_rate_all")));
        result.setOfficialAccountOrderRateDay(ObjectUtil.toDecimal(record.get("official_account_order_rate_day")));
        result.setOfficialAccountOrderCostAll(ObjectUtil.toLong(record.get("official_account_order_cost_all")));
        result.setOfficialAccountOrderCostDay(ObjectUtil.toLong(record.get("official_account_order_cost_day")));
        result.setOfficialAccountOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_order_amount_total")));
        result.setOfficialAccountOrderAmountDay(ObjectUtil.toLong(record.get("official_account_order_amount_day")));
        result.setOfficialAccountFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_total")));
        result.setOfficialAccountFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_day")));
        result.setOfficialAccountOrderRoiAll(ObjectUtil.toLong(record.get("official_account_order_roi_all")));
        result.setOfficialAccountOrderRoiDay(ObjectUtil.toLong(record.get("official_account_order_roi_day")));
        result.setOfficialAccountConsultCountTotal(ObjectUtil.toLong(record.get("official_account_consult_count_total")));
        result.setOfficialAccountConsultCountDay(ObjectUtil.toLong(record.get("official_account_consult_count_day")));
        result.setOfficialAccountReaderCountTotal(ObjectUtil.toLong(record.get("official_account_reader_count_total")));
        result.setOfficialAccountReaderCountDay(ObjectUtil.toLong(record.get("official_account_reader_count_day")));
        result.setOfficialAccountCreditApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_total")));
        result.setOfficialAccountCreditApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_day")));
        result.setOfficialAccountCreditUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_user_count_total")));
        result.setOfficialAccountCreditUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_user_count_day")));
        result.setForwardCountTotal(ObjectUtil.toLong(record.get("forward_count_total")));
        result.setForwardCountDay(ObjectUtil.toLong(record.get("forward_count_day")));
        result.setForwardUserCountTotal(ObjectUtil.toLong(record.get("forward_user_count_total")));
        result.setForwardUserCountDay(ObjectUtil.toLong(record.get("forward_user_count_day")));
        result.setNoInterestCountTotal(ObjectUtil.toLong(record.get("no_interest_count_total")));
        result.setNoInterestCountDay(ObjectUtil.toLong(record.get("no_interest_count_day")));
        return result;
    }

    public static AdStatOfDayDWD completion(LocalDate completionDay, AdStatOfDayDWD lastReduce) {
        String statDay = DateUtil.formatLocalDate(completionDay);
        AdStatOfDayDWD result = new AdStatOfDayDWD();
        BeanUtils.copyProperties(lastReduce, result);
        result.setCreateTime(new Date());
        result.setStatDay(statDay);
        result.setCostDeviationRateDay(BigDecimal.ZERO);
        result.setCostDay(0L);
        result.setCompensationAmountDay(0L);
        result.setViewCountDay(0L);
        result.setThousandDisplayPriceDay(0L);
        result.setViewUserCountDay(0L);
        result.setAvgViewPerUserDay(BigDecimal.ZERO);
        result.setValidClickCountDay(0L);
        result.setClickUserCountDay(0L);
        result.setCtrDay(BigDecimal.ZERO);
        result.setCpcDay(0L);
        result.setValuableClickCountDay(0L);
        result.setValuableClickRateDay(BigDecimal.ZERO);
        result.setValuableClickCostDay(0L);
        result.setConversionsCountDay(0L);
        result.setConversionsCostDay(0L);
        result.setConversionsRateDay(BigDecimal.ZERO);
        result.setDeepConversionsCountDay(0L);
        result.setDeepConversionsCostDay(0L);
        result.setDeepConversionsRateDay(BigDecimal.ZERO);
        result.setKeyPageUvDay(0L);
        result.setOrderCountDay(0L);
        result.setFirstDayOrderCountDay(0L);
        result.setWebOrderCostDay(0L);
        result.setOrderRateDay(BigDecimal.ZERO);
        result.setOrderAmountDay(0L);
        result.setFirstDayOrderAmountDay(0L);
        result.setOrderUnitPriceDay(0L);
        result.setOrderRoiDay(BigDecimal.ZERO);
        result.setSignInCountDay(0L);
        result.setAddWishlistCountDay(0L);
        result.setViewCommodityPageUvDay(0L);
        result.setPageReservationCountDay(0L);
        result.setLeadsPurchaseUvDay(0L);
        result.setLeadsPurchaseCostDay(0L);
        result.setLeadsPurchaseRateDay(BigDecimal.ZERO);
        result.setScanFollowCountDay(0L);
        result.setWechatAppRegisterUvDay(0L);
        result.setWechatMinigameRegisterCostDay(0L);
        result.setWechatMinigameRegisterRateDay(BigDecimal.ZERO);
        result.setWechatMinigameArpuDay(BigDecimal.ZERO);
        result.setWechatMinigameRetentionCountDay(0L);
        result.setWechatMinigameCheckoutCountDay(0L);
        result.setWechatMinigameCheckoutAmountDay(0L);
        result.setOfficialAccountFollowCountDay(0L);
        result.setOfficialAccountFollowCostDay(0L);
        result.setOfficialAccountFollowRateDay(BigDecimal.ZERO);
        result.setOfficialAccountRegisterUserCountDay(0L);
        result.setOfficialAccountRegisterRateDay(BigDecimal.ZERO);
        result.setOfficialAccountRegisterCostDay(0L);
        result.setOfficialAccountRegisterAmountDay(0L);
        result.setOfficialAccountRegisterRoiDay(0L);
        result.setOfficialAccountApplyCountDay(0L);
        result.setOfficialAccountApplyUserCountDay(0L);
        result.setOfficialAccountApplyRateDay(BigDecimal.ZERO);
        result.setOfficialAccountApplyCostDay(0L);
        result.setOfficialAccountApplyAmountDay(0L);
        result.setOfficialAccountApplyRoiDay(0L);
        result.setOfficialAccountOrderCountDay(0L);
        result.setOfficialAccountFirstDayOrderCountDay(0L);
        result.setOfficialAccountOrderUserCountDay(0L);
        result.setOfficialAccountOrderRateDay(BigDecimal.ZERO);
        result.setOfficialAccountOrderCostDay(0L);
        result.setOfficialAccountOrderAmountDay(0L);
        result.setOfficialAccountFirstDayOrderAmountDay(0L);
        result.setOfficialAccountOrderRoiDay(0L);
        result.setOfficialAccountConsultCountDay(0L);
        result.setOfficialAccountReaderCountDay(0L);
        result.setOfficialAccountCreditApplyUserCountDay(0L);
        result.setOfficialAccountCreditUserCountDay(0L);
        result.setForwardCountDay(0L);
        result.setForwardUserCountDay(0L);
        result.setNoInterestCountDay(0L);
        return result;
    }

    public static AdStatOfDayDWD byHourDWD(AdStatOfHourDWD hourDWD) {
        AdStatOfDayDWD result = new AdStatOfDayDWD();
        BeanUtils.copyProperties(hourDWD, result);
        result.setViewUserCountTotal(0L);
        result.setViewUserCountDay(0L);
        result.setAvgViewPerUserAll(BigDecimal.ZERO);
        result.setAvgViewPerUserDay(BigDecimal.ZERO);
        result.setClickUserCountTotal(0L);
        result.setClickUserCountDay(0L);
        result.setKeyPageUvTotal(0L);
        result.setKeyPageUvDay(0L);
        result.setAddWishlistCountTotal(0L);
        result.setAddWishlistCountDay(0L);
        result.setViewCommodityPageUvTotal(0L);
        result.setViewCommodityPageUvDay(0L);
        result.setPageReservationCountTotal(0L);
        result.setPageReservationCountDay(0L);
        result.setLeadsPurchaseUvTotal(0L);
        result.setLeadsPurchaseUvDay(0L);
        result.setLeadsPurchaseCostAll(0L);
        result.setLeadsPurchaseCostDay(0L);
        result.setLeadsPurchaseRateAll(BigDecimal.ZERO);
        result.setLeadsPurchaseRateDay(BigDecimal.ZERO);
        result.setOfficialAccountFollowCostAll(0L);
        result.setOfficialAccountFollowCostDay(0L);
        return result;
    }

    public void removeNull() {

        if (statDay == null) {
            statDay = "";
        }

        if (accountId == null) {
            accountId = 0L;
        }

        if (campaignId == null) {
            campaignId = 0L;
        }

        if (agencyAccountId == null) {
            agencyAccountId = 0L;
        }

        if (wechatAccountId == null) {
            wechatAccountId = "";
        }

        if (wechatAgencyId == null) {
            wechatAgencyId = "";
        }

        if (adgroupId == null) {
            adgroupId = 0L;
        }

        if (adId == null) {
            adId = 0L;
        }

        if (createTime == null) {
            createTime = new Date();
        }

        if (costDeviationRateTotal == null) {
            costDeviationRateTotal = BigDecimal.ZERO;
        }

        if (costDeviationRateDay == null) {
            costDeviationRateDay = BigDecimal.ZERO;
        }

        if (costTotal == null) {
            costTotal = 0L;
        }

        if (costDay == null) {
            costDay = 0L;
        }

        if (compensationAmountTotal == null) {
            compensationAmountTotal = 0L;
        }

        if (compensationAmountDay == null) {
            compensationAmountDay = 0L;
        }

        if (viewCountTotal == null) {
            viewCountTotal = 0L;
        }

        if (viewCountDay == null) {
            viewCountDay = 0L;
        }

        if (thousandDisplayPriceAll == null) {
            thousandDisplayPriceAll = 0L;
        }

        if (thousandDisplayPriceDay == null) {
            thousandDisplayPriceDay = 0L;
        }

        if (viewUserCountTotal == null) {
            viewUserCountTotal = 0L;
        }

        if (viewUserCountDay == null) {
            viewUserCountDay = 0L;
        }

        if (avgViewPerUserAll == null) {
            avgViewPerUserAll = BigDecimal.ZERO;
        }

        if (avgViewPerUserDay == null) {
            avgViewPerUserDay = BigDecimal.ZERO;
        }

        if (validClickCountTotal == null) {
            validClickCountTotal = 0L;
        }

        if (validClickCountDay == null) {
            validClickCountDay = 0L;
        }

        if (clickUserCountTotal == null) {
            clickUserCountTotal = 0L;
        }

        if (clickUserCountDay == null) {
            clickUserCountDay = 0L;
        }

        if (ctrAll == null) {
            ctrAll = BigDecimal.ZERO;
        }

        if (ctrDay == null) {
            ctrDay = BigDecimal.ZERO;
        }

        if (cpcAll == null) {
            cpcAll = 0L;
        }

        if (cpcDay == null) {
            cpcDay = 0L;
        }

        if (valuableClickCountTotal == null) {
            valuableClickCountTotal = 0L;
        }

        if (valuableClickCountDay == null) {
            valuableClickCountDay = 0L;
        }

        if (valuableClickRateAll == null) {
            valuableClickRateAll = BigDecimal.ZERO;
        }

        if (valuableClickRateDay == null) {
            valuableClickRateDay = BigDecimal.ZERO;
        }

        if (valuableClickCostAll == null) {
            valuableClickCostAll = 0L;
        }

        if (valuableClickCostDay == null) {
            valuableClickCostDay = 0L;
        }

        if (conversionsCountTotal == null) {
            conversionsCountTotal = 0L;
        }

        if (conversionsCountDay == null) {
            conversionsCountDay = 0L;
        }

        if (conversionsCostAll == null) {
            conversionsCostAll = 0L;
        }

        if (conversionsCostDay == null) {
            conversionsCostDay = 0L;
        }

        if (conversionsRateAll == null) {
            conversionsRateAll = BigDecimal.ZERO;
        }

        if (conversionsRateDay == null) {
            conversionsRateDay = BigDecimal.ZERO;
        }

        if (deepConversionsCountTotal == null) {
            deepConversionsCountTotal = 0L;
        }

        if (deepConversionsCountDay == null) {
            deepConversionsCountDay = 0L;
        }

        if (deepConversionsCostAll == null) {
            deepConversionsCostAll = 0L;
        }

        if (deepConversionsCostDay == null) {
            deepConversionsCostDay = 0L;
        }

        if (deepConversionsRateAll == null) {
            deepConversionsRateAll = BigDecimal.ZERO;
        }

        if (deepConversionsRateDay == null) {
            deepConversionsRateDay = BigDecimal.ZERO;
        }

        if (keyPageUvTotal == null) {
            keyPageUvTotal = 0L;
        }

        if (keyPageUvDay == null) {
            keyPageUvDay = 0L;
        }

        if (orderCountTotal == null) {
            orderCountTotal = 0L;
        }

        if (orderCountDay == null) {
            orderCountDay = 0L;
        }

        if (firstDayOrderCountTotal == null) {
            firstDayOrderCountTotal = 0L;
        }

        if (firstDayOrderCountDay == null) {
            firstDayOrderCountDay = 0L;
        }

        if (webOrderCostAll == null) {
            webOrderCostAll = 0L;
        }

        if (webOrderCostDay == null) {
            webOrderCostDay = 0L;
        }

        if (orderRateAll == null) {
            orderRateAll = BigDecimal.ZERO;
        }

        if (orderRateDay == null) {
            orderRateDay = BigDecimal.ZERO;
        }

        if (orderAmountTotal == null) {
            orderAmountTotal = 0L;
        }

        if (orderAmountDay == null) {
            orderAmountDay = 0L;
        }

        if (firstDayOrderAmountTotal == null) {
            firstDayOrderAmountTotal = 0L;
        }

        if (firstDayOrderAmountDay == null) {
            firstDayOrderAmountDay = 0L;
        }

        if (orderUnitPriceAll == null) {
            orderUnitPriceAll = 0L;
        }

        if (orderUnitPriceDay == null) {
            orderUnitPriceDay = 0L;
        }

        if (orderRoiAll == null) {
            orderRoiAll = BigDecimal.ZERO;
        }

        if (orderRoiDay == null) {
            orderRoiDay = BigDecimal.ZERO;
        }

        if (signInCountTotal == null) {
            signInCountTotal = 0L;
        }

        if (signInCountDay == null) {
            signInCountDay = 0L;
        }

        if (addWishlistCountTotal == null) {
            addWishlistCountTotal = 0L;
        }

        if (addWishlistCountDay == null) {
            addWishlistCountDay = 0L;
        }

        if (viewCommodityPageUvTotal == null) {
            viewCommodityPageUvTotal = 0L;
        }

        if (viewCommodityPageUvDay == null) {
            viewCommodityPageUvDay = 0L;
        }

        if (pageReservationCountTotal == null) {
            pageReservationCountTotal = 0L;
        }

        if (pageReservationCountDay == null) {
            pageReservationCountDay = 0L;
        }

        if (leadsPurchaseUvTotal == null) {
            leadsPurchaseUvTotal = 0L;
        }

        if (leadsPurchaseUvDay == null) {
            leadsPurchaseUvDay = 0L;
        }

        if (leadsPurchaseCostAll == null) {
            leadsPurchaseCostAll = 0L;
        }

        if (leadsPurchaseCostDay == null) {
            leadsPurchaseCostDay = 0L;
        }

        if (leadsPurchaseRateAll == null) {
            leadsPurchaseRateAll = BigDecimal.ZERO;
        }

        if (leadsPurchaseRateDay == null) {
            leadsPurchaseRateDay = BigDecimal.ZERO;
        }

        if (scanFollowCountTotal == null) {
            scanFollowCountTotal = 0L;
        }

        if (scanFollowCountDay == null) {
            scanFollowCountDay = 0L;
        }

        if (wechatAppRegisterUvTotal == null) {
            wechatAppRegisterUvTotal = 0L;
        }

        if (wechatAppRegisterUvDay == null) {
            wechatAppRegisterUvDay = 0L;
        }

        if (wechatMinigameRegisterCostAll == null) {
            wechatMinigameRegisterCostAll = 0L;
        }

        if (wechatMinigameRegisterCostDay == null) {
            wechatMinigameRegisterCostDay = 0L;
        }

        if (wechatMinigameRegisterRateAll == null) {
            wechatMinigameRegisterRateAll = BigDecimal.ZERO;
        }

        if (wechatMinigameRegisterRateDay == null) {
            wechatMinigameRegisterRateDay = BigDecimal.ZERO;
        }

        if (wechatMinigameArpuAll == null) {
            wechatMinigameArpuAll = BigDecimal.ZERO;
        }

        if (wechatMinigameArpuDay == null) {
            wechatMinigameArpuDay = BigDecimal.ZERO;
        }

        if (wechatMinigameRetentionCountTotal == null) {
            wechatMinigameRetentionCountTotal = 0L;
        }

        if (wechatMinigameRetentionCountDay == null) {
            wechatMinigameRetentionCountDay = 0L;
        }

        if (wechatMinigameCheckoutCountTotal == null) {
            wechatMinigameCheckoutCountTotal = 0L;
        }

        if (wechatMinigameCheckoutCountDay == null) {
            wechatMinigameCheckoutCountDay = 0L;
        }

        if (wechatMinigameCheckoutAmountTotal == null) {
            wechatMinigameCheckoutAmountTotal = 0L;
        }

        if (wechatMinigameCheckoutAmountDay == null) {
            wechatMinigameCheckoutAmountDay = 0L;
        }

        if (officialAccountFollowCountTotal == null) {
            officialAccountFollowCountTotal = 0L;
        }

        if (officialAccountFollowCountDay == null) {
            officialAccountFollowCountDay = 0L;
        }

        if (officialAccountFollowCostAll == null) {
            officialAccountFollowCostAll = 0L;
        }

        if (officialAccountFollowCostDay == null) {
            officialAccountFollowCostDay = 0L;
        }

        if (officialAccountFollowRateAll == null) {
            officialAccountFollowRateAll = BigDecimal.ZERO;
        }

        if (officialAccountFollowRateDay == null) {
            officialAccountFollowRateDay = BigDecimal.ZERO;
        }

        if (officialAccountRegisterUserCountTotal == null) {
            officialAccountRegisterUserCountTotal = 0L;
        }

        if (officialAccountRegisterUserCountDay == null) {
            officialAccountRegisterUserCountDay = 0L;
        }

        if (officialAccountRegisterRateAll == null) {
            officialAccountRegisterRateAll = BigDecimal.ZERO;
        }

        if (officialAccountRegisterRateDay == null) {
            officialAccountRegisterRateDay = BigDecimal.ZERO;
        }

        if (officialAccountRegisterCostAll == null) {
            officialAccountRegisterCostAll = 0L;
        }

        if (officialAccountRegisterCostDay == null) {
            officialAccountRegisterCostDay = 0L;
        }

        if (officialAccountRegisterAmountTotal == null) {
            officialAccountRegisterAmountTotal = 0L;
        }

        if (officialAccountRegisterAmountDay == null) {
            officialAccountRegisterAmountDay = 0L;
        }

        if (officialAccountRegisterRoiAll == null) {
            officialAccountRegisterRoiAll = 0L;
        }

        if (officialAccountRegisterRoiDay == null) {
            officialAccountRegisterRoiDay = 0L;
        }

        if (officialAccountApplyCountTotal == null) {
            officialAccountApplyCountTotal = 0L;
        }

        if (officialAccountApplyCountDay == null) {
            officialAccountApplyCountDay = 0L;
        }

        if (officialAccountApplyUserCountTotal == null) {
            officialAccountApplyUserCountTotal = 0L;
        }

        if (officialAccountApplyUserCountDay == null) {
            officialAccountApplyUserCountDay = 0L;
        }

        if (officialAccountApplyRateAll == null) {
            officialAccountApplyRateAll = BigDecimal.ZERO;
        }

        if (officialAccountApplyRateDay == null) {
            officialAccountApplyRateDay = BigDecimal.ZERO;
        }

        if (officialAccountApplyCostAll == null) {
            officialAccountApplyCostAll = 0L;
        }

        if (officialAccountApplyCostDay == null) {
            officialAccountApplyCostDay = 0L;
        }

        if (officialAccountApplyAmountTotal == null) {
            officialAccountApplyAmountTotal = 0L;
        }

        if (officialAccountApplyAmountDay == null) {
            officialAccountApplyAmountDay = 0L;
        }

        if (officialAccountApplyRoiAll == null) {
            officialAccountApplyRoiAll = 0L;
        }

        if (officialAccountApplyRoiDay == null) {
            officialAccountApplyRoiDay = 0L;
        }

        if (officialAccountOrderCountTotal == null) {
            officialAccountOrderCountTotal = 0L;
        }

        if (officialAccountOrderCountDay == null) {
            officialAccountOrderCountDay = 0L;
        }

        if (officialAccountFirstDayOrderCountTotal == null) {
            officialAccountFirstDayOrderCountTotal = 0L;
        }

        if (officialAccountFirstDayOrderCountDay == null) {
            officialAccountFirstDayOrderCountDay = 0L;
        }

        if (officialAccountOrderUserCountTotal == null) {
            officialAccountOrderUserCountTotal = 0L;
        }

        if (officialAccountOrderUserCountDay == null) {
            officialAccountOrderUserCountDay = 0L;
        }

        if (officialAccountOrderRateAll == null) {
            officialAccountOrderRateAll = BigDecimal.ZERO;
        }

        if (officialAccountOrderRateDay == null) {
            officialAccountOrderRateDay = BigDecimal.ZERO;
        }

        if (officialAccountOrderCostAll == null) {
            officialAccountOrderCostAll = 0L;
        }

        if (officialAccountOrderCostDay == null) {
            officialAccountOrderCostDay = 0L;
        }

        if (officialAccountOrderAmountTotal == null) {
            officialAccountOrderAmountTotal = 0L;
        }

        if (officialAccountOrderAmountDay == null) {
            officialAccountOrderAmountDay = 0L;
        }

        if (officialAccountFirstDayOrderAmountTotal == null) {
            officialAccountFirstDayOrderAmountTotal = 0L;
        }

        if (officialAccountFirstDayOrderAmountDay == null) {
            officialAccountFirstDayOrderAmountDay = 0L;
        }

        if (officialAccountOrderRoiAll == null) {
            officialAccountOrderRoiAll = 0L;
        }

        if (officialAccountOrderRoiDay == null) {
            officialAccountOrderRoiDay = 0L;
        }

        if (officialAccountConsultCountTotal == null) {
            officialAccountConsultCountTotal = 0L;
        }

        if (officialAccountConsultCountDay == null) {
            officialAccountConsultCountDay = 0L;
        }

        if (officialAccountReaderCountTotal == null) {
            officialAccountReaderCountTotal = 0L;
        }

        if (officialAccountReaderCountDay == null) {
            officialAccountReaderCountDay = 0L;
        }

        if (officialAccountCreditApplyUserCountTotal == null) {
            officialAccountCreditApplyUserCountTotal = 0L;
        }

        if (officialAccountCreditApplyUserCountDay == null) {
            officialAccountCreditApplyUserCountDay = 0L;
        }

        if (officialAccountCreditUserCountTotal == null) {
            officialAccountCreditUserCountTotal = 0L;
        }

        if (officialAccountCreditUserCountDay == null) {
            officialAccountCreditUserCountDay = 0L;
        }

        if (forwardCountTotal == null) {
            forwardCountTotal = 0L;
        }

        if (forwardCountDay == null) {
            forwardCountDay = 0L;
        }

        if (forwardUserCountTotal == null) {
            forwardUserCountTotal = 0L;
        }

        if (forwardUserCountDay == null) {
            forwardUserCountDay = 0L;
        }

        if (noInterestCountTotal == null) {
            noInterestCountTotal = 0L;
        }

        if (noInterestCountDay == null) {
            noInterestCountDay = 0L;
        }
    }
}
