package flink.zanxiangnet.ad.monitoring.pojo.entity;

import com.aliyun.odps.data.Record;
import com.google.gson.annotations.SerializedName;
import com.zanxiangnet.module.util.DateUtil;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.BeanUtil;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeColumn;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import flink.zanxiangnet.ad.monitoring.util.NumberUtil;
import flink.zanxiangnet.ad.monitoring.util.ObjectUtil;
import lombok.Data;
import org.springframework.beans.BeanUtils;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;

/**
 * 广告维度的小时统计数据
 */
@Data
@MaxComputeTable("ad_stat_of_hour_dwd")
public class AdStatOfHourDWD {

    /**
     * 统计的日期（用于 MaxCompute分区）
     */
    @MaxComputeColumn(isPartitioned = true)
    @SerializedName("stat_day")
    private String statDay;

    /**
     * 统计的小时
     */
    @SerializedName("hour")
    private Integer hour;

    /**
     * 腾讯广告应用的账号 id
     */
    @SerializedName("account_id")
    private Long accountId;

    /**
     * 计划 id
     */
    @SerializedName("campaign_id")
    private Long campaignId;

    /**
     * 服务商账号 id
     */
    @SerializedName("agency_account_id")
    private Long agencyAccountId;

    /**
     * 微信账号id
     */
    @SerializedName("wechat_account_id")
    private String wechatAccountId;

    /**
     * 微信服务商id
     */
    @SerializedName("wechat_agency_id")
    private String wechatAgencyId;

    /**
     * 广告组 id
     */
    @SerializedName("adgroup_id")
    private Long adgroupId;

    /**
     * 广告 id
     */
    @SerializedName("ad_id")
    private Long adId;

    /**
     * 记录创建时间
     */
    @SerializedName("create_time")
    private Date createTime;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_total")
    private BigDecimal costDeviationRateTotal;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_day")
    private BigDecimal costDeviationRateDay;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_hour")
    private BigDecimal costDeviationRateHour;

    /**
     * 消耗
     */
    @SerializedName("cost_total")
    private Long costTotal;

    /**
     * 消耗
     */
    @SerializedName("cost_day")
    private Long costDay;

    /**
     * 消耗
     */
    @SerializedName("cost_hour")
    private Long costHour;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_total")
    private Long compensationAmountTotal;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_day")
    private Long compensationAmountDay;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_hour")
    private Long compensationAmountHour;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_total")
    private Long viewCountTotal;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_day")
    private Long viewCountDay;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_hour")
    private Long viewCountHour;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_all")
    private Long thousandDisplayPriceAll;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_day")
    private Long thousandDisplayPriceDay;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_hour")
    private Long thousandDisplayPriceHour;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_hour")
    private BigDecimal avgViewPerUserHour;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_total")
    private Long validClickCountTotal;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_day")
    private Long validClickCountDay;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_hour")
    private Long validClickCountHour;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_all")
    private BigDecimal ctrAll;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_day")
    private BigDecimal ctrDay;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_hour")
    private BigDecimal ctrHour;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_all")
    private Long cpcAll;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_day")
    private Long cpcDay;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_hour")
    private Long cpcHour;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_total")
    private Long valuableClickCountTotal;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_day")
    private Long valuableClickCountDay;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_hour")
    private Long valuableClickCountHour;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_all")
    private BigDecimal valuableClickRateAll;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_day")
    private BigDecimal valuableClickRateDay;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_hour")
    private BigDecimal valuableClickRateHour;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_all")
    private Long valuableClickCostAll;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_day")
    private Long valuableClickCostDay;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_hour")
    private Long valuableClickCostHour;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_total")
    private Long conversionsCountTotal;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_day")
    private Long conversionsCountDay;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_hour")
    private Long conversionsCountHour;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_all")
    private Long conversionsCostAll;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_day")
    private Long conversionsCostDay;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_hour")
    private Long conversionsCostHour;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_all")
    private BigDecimal conversionsRateAll;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_day")
    private BigDecimal conversionsRateDay;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_hour")
    private BigDecimal conversionsRateHour;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_total")
    private Long deepConversionsCountTotal;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_day")
    private Long deepConversionsCountDay;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_hour")
    private Long deepConversionsCountHour;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_all")
    private Long deepConversionsCostAll;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_day")
    private Long deepConversionsCostDay;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_hour")
    private Long deepConversionsCostHour;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_all")
    private BigDecimal deepConversionsRateAll;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_day")
    private BigDecimal deepConversionsRateDay;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_hour")
    private BigDecimal deepConversionsRateHour;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_total")
    private Long orderCountTotal;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_day")
    private Long orderCountDay;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_hour")
    private Long orderCountHour;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_total")
    private Long firstDayOrderCountTotal;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_day")
    private Long firstDayOrderCountDay;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_hour")
    private Long firstDayOrderCountHour;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_all")
    private Long webOrderCostAll;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_day")
    private Long webOrderCostDay;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_hour")
    private Long webOrderCostHour;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_all")
    private BigDecimal orderRateAll;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_day")
    private BigDecimal orderRateDay;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_hour")
    private BigDecimal orderRateHour;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_total")
    private Long orderAmountTotal;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_day")
    private Long orderAmountDay;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_hour")
    private Long orderAmountHour;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_total")
    private Long firstDayOrderAmountTotal;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_day")
    private Long firstDayOrderAmountDay;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_hour")
    private Long firstDayOrderAmountHour;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_all")
    private Long orderUnitPriceAll;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_day")
    private Long orderUnitPriceDay;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_hour")
    private Long orderUnitPriceHour;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_all")
    private BigDecimal orderRoiAll;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_day")
    private BigDecimal orderRoiDay;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_hour")
    private BigDecimal orderRoiHour;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_total")
    private Long signInCountTotal;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_day")
    private Long signInCountDay;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_hour")
    private Long signInCountHour;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_total")
    private Long scanFollowCountTotal;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_day")
    private Long scanFollowCountDay;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_hour")
    private Long scanFollowCountHour;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_total")
    private Long wechatAppRegisterUvTotal;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_day")
    private Long wechatAppRegisterUvDay;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_hour")
    private Long wechatAppRegisterUvHour;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_all")
    private Long wechatMinigameRegisterCostAll;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_day")
    private Long wechatMinigameRegisterCostDay;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_hour")
    private Long wechatMinigameRegisterCostHour;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_all")
    private BigDecimal wechatMinigameRegisterRateAll;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_day")
    private BigDecimal wechatMinigameRegisterRateDay;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_hour")
    private BigDecimal wechatMinigameRegisterRateHour;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_all")
    private BigDecimal wechatMinigameArpuAll;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_day")
    private BigDecimal wechatMinigameArpuDay;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_hour")
    private BigDecimal wechatMinigameArpuHour;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_total")
    private Long wechatMinigameRetentionCountTotal;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_day")
    private Long wechatMinigameRetentionCountDay;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_hour")
    private Long wechatMinigameRetentionCountHour;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_total")
    private Long wechatMinigameCheckoutCountTotal;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_day")
    private Long wechatMinigameCheckoutCountDay;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_hour")
    private Long wechatMinigameCheckoutCountHour;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_total")
    private Long wechatMinigameCheckoutAmountTotal;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_day")
    private Long wechatMinigameCheckoutAmountDay;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_hour")
    private Long wechatMinigameCheckoutAmountHour;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_total")
    private Long officialAccountFollowCountTotal;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_day")
    private Long officialAccountFollowCountDay;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_hour")
    private Long officialAccountFollowCountHour;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_all")
    private BigDecimal officialAccountFollowRateAll;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_day")
    private BigDecimal officialAccountFollowRateDay;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_hour")
    private BigDecimal officialAccountFollowRateHour;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_total")
    private Long officialAccountRegisterUserCountTotal;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_day")
    private Long officialAccountRegisterUserCountDay;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_hour")
    private Long officialAccountRegisterUserCountHour;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_all")
    private BigDecimal officialAccountRegisterRateAll;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_day")
    private BigDecimal officialAccountRegisterRateDay;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_hour")
    private BigDecimal officialAccountRegisterRateHour;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_all")
    private Long officialAccountRegisterCostAll;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_day")
    private Long officialAccountRegisterCostDay;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_hour")
    private Long officialAccountRegisterCostHour;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_total")
    private Long officialAccountRegisterAmountTotal;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_day")
    private Long officialAccountRegisterAmountDay;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_hour")
    private Long officialAccountRegisterAmountHour;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_all")
    private Long officialAccountRegisterRoiAll;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_day")
    private Long officialAccountRegisterRoiDay;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_hour")
    private Long officialAccountRegisterRoiHour;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_total")
    private Long officialAccountApplyCountTotal;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_day")
    private Long officialAccountApplyCountDay;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_hour")
    private Long officialAccountApplyCountHour;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_total")
    private Long officialAccountApplyUserCountTotal;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_day")
    private Long officialAccountApplyUserCountDay;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_hour")
    private Long officialAccountApplyUserCountHour;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_all")
    private BigDecimal officialAccountApplyRateAll;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_day")
    private BigDecimal officialAccountApplyRateDay;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_hour")
    private BigDecimal officialAccountApplyRateHour;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_all")
    private Long officialAccountApplyCostAll;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_day")
    private Long officialAccountApplyCostDay;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_hour")
    private Long officialAccountApplyCostHour;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_total")
    private Long officialAccountApplyAmountTotal;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_day")
    private Long officialAccountApplyAmountDay;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_hour")
    private Long officialAccountApplyAmountHour;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_all")
    private Long officialAccountApplyRoiAll;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_day")
    private Long officialAccountApplyRoiDay;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_hour")
    private Long officialAccountApplyRoiHour;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_total")
    private Long officialAccountOrderCountTotal;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_day")
    private Long officialAccountOrderCountDay;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_hour")
    private Long officialAccountOrderCountHour;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_total")
    private Long officialAccountFirstDayOrderCountTotal;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_day")
    private Long officialAccountFirstDayOrderCountDay;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_hour")
    private Long officialAccountFirstDayOrderCountHour;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_total")
    private Long officialAccountOrderUserCountTotal;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_day")
    private Long officialAccountOrderUserCountDay;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_hour")
    private Long officialAccountOrderUserCountHour;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_all")
    private BigDecimal officialAccountOrderRateAll;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_day")
    private BigDecimal officialAccountOrderRateDay;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_hour")
    private BigDecimal officialAccountOrderRateHour;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_all")
    private Long officialAccountOrderCostAll;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_day")
    private Long officialAccountOrderCostDay;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_hour")
    private Long officialAccountOrderCostHour;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_total")
    private Long officialAccountOrderAmountTotal;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_day")
    private Long officialAccountOrderAmountDay;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_hour")
    private Long officialAccountOrderAmountHour;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_total")
    private Long officialAccountFirstDayOrderAmountTotal;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_day")
    private Long officialAccountFirstDayOrderAmountDay;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_hour")
    private Long officialAccountFirstDayOrderAmountHour;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_all")
    private Long officialAccountOrderRoiAll;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_day")
    private Long officialAccountOrderRoiDay;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_hour")
    private Long officialAccountOrderRoiHour;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_total")
    private Long officialAccountConsultCountTotal;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_day")
    private Long officialAccountConsultCountDay;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_hour")
    private Long officialAccountConsultCountHour;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_total")
    private Long officialAccountReaderCountTotal;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_day")
    private Long officialAccountReaderCountDay;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_hour")
    private Long officialAccountReaderCountHour;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_total")
    private Long officialAccountCreditApplyUserCountTotal;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_day")
    private Long officialAccountCreditApplyUserCountDay;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_hour")
    private Long officialAccountCreditApplyUserCountHour;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_total")
    private Long officialAccountCreditUserCountTotal;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_day")
    private Long officialAccountCreditUserCountDay;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_hour")
    private Long officialAccountCreditUserCountHour;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_total")
    private Long forwardCountTotal;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_day")
    private Long forwardCountDay;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_hour")
    private Long forwardCountHour;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_total")
    private Long forwardUserCountTotal;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_day")
    private Long forwardUserCountDay;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_hour")
    private Long forwardUserCountHour;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_total")
    private Long noInterestCountTotal;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_day")
    private Long noInterestCountDay;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_hour")
    private Long noInterestCountHour;

    public static AdStatOfHourDWD byMinuteDWD(AdStatOfMinuteDWD minuteDWD) {
        AdStatOfHourDWD result = new AdStatOfHourDWD();
        BeanUtils.copyProperties(minuteDWD, result);
        return result;
    }

    public static AdStatOfHourDWD byODS(AdDataOfHourODS adODS) {
        AdStatOfHourDWD adStatOfHour = new AdStatOfHourDWD();
        adStatOfHour.setStatDay(adODS.getStatDay());
        adStatOfHour.setHour(adODS.getHour());
        adStatOfHour.setAccountId(adODS.getAccountId());
        adStatOfHour.setCampaignId(adODS.getCampaignId());
        adStatOfHour.setAgencyAccountId(adODS.getAgencyAccountId());
        adStatOfHour.setWechatAccountId(adODS.getWechatAccountId());
        adStatOfHour.setWechatAgencyId(adODS.getWechatAgencyId());
        adStatOfHour.setAdgroupId(adODS.getAdgroupId());
        adStatOfHour.setAdId(adODS.getAdId());
        adStatOfHour.setCostDeviationRateHour(adODS.getCostDeviationRate());
        adStatOfHour.setCostHour(adODS.getCost());
        adStatOfHour.setCompensationAmountHour(adODS.getCompensationAmount());
        adStatOfHour.setViewCountHour(adODS.getViewCount());
        adStatOfHour.setThousandDisplayPriceHour(adODS.getThousandDisplayPrice());
        adStatOfHour.setAvgViewPerUserHour(adODS.getAvgViewPerUser());
        adStatOfHour.setValidClickCountHour(adODS.getValidClickCount());
        adStatOfHour.setCtrHour(adODS.getCtr());
        adStatOfHour.setCpcHour(adODS.getCpc());
        adStatOfHour.setValuableClickCountHour(adODS.getValuableClickCount());
        adStatOfHour.setValuableClickRateHour(adODS.getValuableClickRate());
        adStatOfHour.setValuableClickCostHour(adODS.getValuableClickCost());
        adStatOfHour.setConversionsCountHour(adODS.getConversionsCount());
        adStatOfHour.setConversionsCostHour(adODS.getConversionsCost());
        adStatOfHour.setConversionsRateHour(adODS.getConversionsRate());
        adStatOfHour.setDeepConversionsCountHour(adODS.getDeepConversionsCount());
        adStatOfHour.setDeepConversionsCostHour(adODS.getDeepConversionsCost());
        adStatOfHour.setDeepConversionsRateHour(adODS.getDeepConversionsRate());
        adStatOfHour.setOrderCountHour(adODS.getOrderCount());
        adStatOfHour.setFirstDayOrderCountHour(adODS.getFirstDayOrderCount());
        adStatOfHour.setWebOrderCostHour(adODS.getWebOrderCost());
        adStatOfHour.setOrderRateHour(adODS.getOrderRate());
        adStatOfHour.setOrderAmountHour(adODS.getOrderAmount());
        adStatOfHour.setFirstDayOrderAmountHour(adODS.getFirstDayOrderAmount());
        adStatOfHour.setOrderUnitPriceHour(adODS.getOrderUnitPrice());
        adStatOfHour.setOrderRoiHour(adODS.getOrderRoi());
        adStatOfHour.setSignInCountHour(adODS.getSignInCount());
        adStatOfHour.setScanFollowCountHour(adODS.getScanFollowCount());
        adStatOfHour.setWechatAppRegisterUvHour(adODS.getWechatAppRegisterUv());
        adStatOfHour.setWechatMinigameRegisterCostHour(adODS.getWechatMinigameRegisterCost());
        adStatOfHour.setWechatMinigameRegisterRateHour(adODS.getWechatMinigameRegisterRate());
        adStatOfHour.setWechatMinigameArpuHour(adODS.getWechatMinigameArpu());
        adStatOfHour.setWechatMinigameRetentionCountHour(adODS.getWechatMinigameRetentionCount());
        adStatOfHour.setWechatMinigameCheckoutCountHour(adODS.getWechatMinigameCheckoutCount());
        adStatOfHour.setWechatMinigameCheckoutAmountHour(adODS.getWechatMinigameCheckoutAmount());
        adStatOfHour.setOfficialAccountFollowCountHour(adODS.getOfficialAccountFollowCount());
        adStatOfHour.setOfficialAccountFollowRateHour(adODS.getOfficialAccountFollowRate());
        adStatOfHour.setOfficialAccountRegisterUserCountHour(adODS.getOfficialAccountRegisterUserCount());
        adStatOfHour.setOfficialAccountRegisterRateHour(adODS.getOfficialAccountRegisterRate());
        adStatOfHour.setOfficialAccountRegisterCostHour(adODS.getOfficialAccountRegisterCost());
        adStatOfHour.setOfficialAccountRegisterAmountHour(adODS.getOfficialAccountRegisterAmount());
        adStatOfHour.setOfficialAccountRegisterRoiHour(adODS.getOfficialAccountRegisterRoi());
        adStatOfHour.setOfficialAccountApplyCountHour(adODS.getOfficialAccountApplyCount());
        adStatOfHour.setOfficialAccountApplyUserCountHour(adODS.getOfficialAccountApplyUserCount());
        adStatOfHour.setOfficialAccountApplyRateHour(adODS.getOfficialAccountApplyRate());
        adStatOfHour.setOfficialAccountApplyCostHour(adODS.getOfficialAccountApplyCost());
        adStatOfHour.setOfficialAccountApplyAmountHour(adODS.getOfficialAccountApplyAmount());
        adStatOfHour.setOfficialAccountApplyRoiHour(adODS.getOfficialAccountApplyRoi());
        adStatOfHour.setOfficialAccountOrderCountHour(adODS.getOfficialAccountOrderCount());
        adStatOfHour.setOfficialAccountFirstDayOrderCountHour(adODS.getOfficialAccountFirstDayOrderCount());
        adStatOfHour.setOfficialAccountOrderUserCountHour(adODS.getOfficialAccountOrderUserCount());
        adStatOfHour.setOfficialAccountOrderRateHour(adODS.getOfficialAccountOrderRate());
        adStatOfHour.setOfficialAccountOrderCostHour(adODS.getOfficialAccountOrderCost());
        adStatOfHour.setOfficialAccountOrderAmountHour(adODS.getOfficialAccountOrderAmount());
        adStatOfHour.setOfficialAccountFirstDayOrderAmountHour(adODS.getOfficialAccountFirstDayOrderAmount());
        adStatOfHour.setOfficialAccountOrderRoiHour(adODS.getOfficialAccountOrderRoi());
        adStatOfHour.setOfficialAccountConsultCountHour(adODS.getOfficialAccountConsultCount());
        adStatOfHour.setOfficialAccountReaderCountHour(adODS.getOfficialAccountReaderCount());
        adStatOfHour.setOfficialAccountCreditApplyUserCountHour(adODS.getOfficialAccountCreditApplyUserCount());
        adStatOfHour.setOfficialAccountCreditUserCountHour(adODS.getOfficialAccountCreditUserCount());
        adStatOfHour.setForwardCountHour(adODS.getForwardCount());
        adStatOfHour.setForwardUserCountHour(adODS.getForwardUserCount());
        adStatOfHour.setNoInterestCountHour(adODS.getNoInterestCount());
        return adStatOfHour;
    }

    public static AdStatOfHourDWD reduce(AdStatOfDayDWD yesterdayDWD, List<AdDataOfHourODS> hourODSList, AdDataOfHourODS hourODS, long createTime) {
        AdStatOfHourDWD result = new AdStatOfHourDWD();
        BeanUtils.copyProperties(hourODS, result);
        result.setCreateTime(new Date(createTime));
        // 填充小时数据
        result.setCostDeviationRateHour(hourODS.getCostDeviationRate());
        result.setCostHour(hourODS.getCost());
        result.setCompensationAmountHour(hourODS.getCompensationAmount());
        result.setViewCountHour(hourODS.getViewCount());
        result.setAvgViewPerUserHour(hourODS.getAvgViewPerUser());
        result.setValidClickCountHour(hourODS.getValidClickCount());
        result.setValuableClickCountHour(hourODS.getValuableClickCount());
        result.setConversionsCountHour(hourODS.getConversionsCount());
        result.setDeepConversionsCountHour(hourODS.getDeepConversionsCount());
        result.setOrderCountHour(hourODS.getOrderCount());
        result.setFirstDayOrderCountHour(hourODS.getFirstDayOrderCount());
        result.setOrderAmountHour(hourODS.getOrderAmount());
        result.setFirstDayOrderAmountHour(hourODS.getFirstDayOrderAmount());
        result.setSignInCountHour(hourODS.getSignInCount());
        result.setScanFollowCountHour(hourODS.getScanFollowCount());
        result.setWechatAppRegisterUvHour(hourODS.getWechatAppRegisterUv());
        result.setWechatMinigameRetentionCountHour(hourODS.getWechatMinigameRetentionCount());
        result.setWechatMinigameCheckoutCountHour(hourODS.getWechatMinigameCheckoutCount());
        result.setWechatMinigameCheckoutAmountHour(hourODS.getWechatMinigameCheckoutAmount());
        result.setOfficialAccountFollowCountHour(hourODS.getOfficialAccountFollowCount());
        result.setOfficialAccountRegisterUserCountHour(hourODS.getOfficialAccountRegisterUserCount());
        result.setOfficialAccountRegisterAmountHour(hourODS.getOfficialAccountRegisterAmount());
        result.setOfficialAccountApplyCountHour(hourODS.getOfficialAccountApplyCount());
        result.setOfficialAccountApplyUserCountHour(hourODS.getOfficialAccountApplyUserCount());
        result.setOfficialAccountApplyAmountHour(hourODS.getOfficialAccountApplyAmount());
        result.setOfficialAccountOrderCountHour(hourODS.getOfficialAccountOrderCount());
        result.setOfficialAccountFirstDayOrderCountHour(hourODS.getOfficialAccountFirstDayOrderCount());
        result.setOfficialAccountOrderUserCountHour(hourODS.getOfficialAccountOrderUserCount());
        result.setOfficialAccountOrderAmountHour(hourODS.getOfficialAccountOrderAmount());
        result.setOfficialAccountFirstDayOrderAmountHour(hourODS.getOfficialAccountFirstDayOrderAmount());
        result.setOfficialAccountConsultCountHour(hourODS.getOfficialAccountConsultCount());
        result.setOfficialAccountReaderCountHour(hourODS.getOfficialAccountReaderCount());
        result.setOfficialAccountCreditApplyUserCountHour(hourODS.getOfficialAccountCreditApplyUserCount());
        result.setOfficialAccountCreditUserCountHour(hourODS.getOfficialAccountCreditUserCount());
        result.setForwardCountHour(hourODS.getForwardCount());
        result.setForwardUserCountHour(hourODS.getForwardUserCount());
        result.setNoInterestCountHour(hourODS.getNoInterestCount());

        // 总消耗 / 总曝光
        result.setThousandDisplayPriceHour(result.getViewCountHour() == 0 ? 0 : NumberUtil.divideForAd(result.getCostHour(), result.getViewCountHour()).multiply(new BigDecimal(1000)).longValue());
        // 广告点击次数 / 广告曝光次数
        result.setCtrHour(result.getViewCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValidClickCountHour(), result.getViewCountHour()));
        // 广告花费/广告点击次数
        result.setCpcHour(result.getValidClickCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getValidClickCountHour()));
        // 广告可转化点击次数/广告曝光次数
        result.setValuableClickRateHour(result.getViewCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValuableClickCountHour(), result.getViewCountHour()));
        // 广告花费/可转化点击次数
        result.setValuableClickCostHour(result.getValuableClickCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getValuableClickCountHour()));
        // 广告花费/转化目标量
        result.setConversionsCostHour(result.getConversionsCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getConversionsCountHour()));
        // 公众号：转化目标量/点击次数。
        result.setConversionsRateHour(result.getValidClickCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getConversionsCountHour(), result.getValidClickCountHour()));
        // 广告花费/深度转化目标量
        result.setDeepConversionsCostHour(result.getDeepConversionsCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getDeepConversionsCountHour()));
        // 深度转化目标量/可转化点击次数
        result.setDeepConversionsRateHour(result.getValuableClickCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getDeepConversionsCountHour(), result.getValuableClickCountHour()));
        // 广告花费/下单量
        result.setWebOrderCostHour(result.getOrderCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getOrderCountHour()));
        // 下单量/点击次数
        result.setOrderRateHour(result.getValidClickCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderCountHour(), result.getValidClickCountHour()));
        // 下单金额/下单量
        result.setOrderUnitPriceHour(result.getOrderCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getOrderAmountHour(), result.getOrderCountHour()));
        // 下单金额/广告花费
        result.setOrderRoiHour(result.getCostHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountHour(), result.getCostHour()));
        // 广告消耗 / 小游戏注册人数
        result.setWechatMinigameRegisterCostHour(result.getWechatAppRegisterUvHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getWechatAppRegisterUvHour()));
        // 小游戏注册人数 / 广告点击次数
        result.setWechatMinigameRegisterRateHour(result.getValidClickCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getWechatAppRegisterUvHour(), result.getValidClickCountHour()));
        // 总收益 / 总人数
        result.setWechatMinigameArpuHour(result.getWechatAppRegisterUvHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountHour(), result.getWechatAppRegisterUvHour()));
        // 关注次数 / 点击次数
        result.setOfficialAccountFollowRateHour(result.getValidClickCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountFollowCountHour(), result.getValidClickCountHour()));
        // 公众号内注册人数 / 公众号关注次数
        result.setOfficialAccountRegisterRateHour(result.getOfficialAccountFollowCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountHour(), result.getOfficialAccountFollowCountHour()));
        // 广告消耗 / 广告注册人数
        result.setOfficialAccountRegisterCostHour(result.getOfficialAccountRegisterUserCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getOfficialAccountRegisterUserCountHour()));
        // 注册产生的订单金额累计/广告花费
        result.setOfficialAccountRegisterRoiHour(result.getCostHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountHour(), result.getCostHour()));
        // 公众号内填单的独立用户数/公众号关注次数
        result.setOfficialAccountApplyRateHour(result.getOfficialAccountFollowCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountHour(), result.getOfficialAccountFollowCountHour()));
        // 广告花费/广告产生的填单行为数量
        result.setOfficialAccountApplyCostHour(result.getOfficialAccountApplyUserCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getOfficialAccountApplyUserCountHour()));
        // 填单产生的订单金额累计/广告花费
        result.setOfficialAccountApplyRoiHour(result.getCostHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountHour(), result.getCostHour()));
        // 公众号内下单独立用户数（UV）/公众号关注次数
        result.setOfficialAccountOrderRateHour(result.getOfficialAccountFollowCountHour() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountHour(), result.getOfficialAccountFollowCountHour()));
        // 广告花费/广告产生的下单行为数量
        result.setOfficialAccountOrderCostHour(result.getOfficialAccountOrderCountHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostHour(), result.getOfficialAccountOrderCountHour()));
        // 下单产生的订单金额累计/广告花费
        result.setOfficialAccountOrderRoiHour(result.getCostHour() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountHour(), result.getCostHour()));

        // 聚合天数据
        result.setCostDeviationRateDay(BigDecimal.ZERO);
        result.setCostDay(0L);
        result.setCompensationAmountDay(0L);
        result.setViewCountDay(0L);
        result.setValidClickCountDay(0L);
        result.setValuableClickCountDay(0L);
        result.setConversionsCountDay(0L);
        result.setDeepConversionsCountDay(0L);
        result.setOrderCountDay(0L);
        result.setFirstDayOrderCountDay(0L);
        result.setOrderAmountDay(0L);
        result.setFirstDayOrderAmountDay(0L);
        result.setSignInCountDay(0L);
        result.setScanFollowCountDay(0L);
        result.setWechatAppRegisterUvDay(0L);
        result.setWechatMinigameRetentionCountDay(0L);
        result.setWechatMinigameCheckoutCountDay(0L);
        result.setWechatMinigameCheckoutAmountDay(0L);
        result.setOfficialAccountFollowCountDay(0L);
        result.setOfficialAccountRegisterUserCountDay(0L);
        result.setOfficialAccountRegisterAmountDay(0L);
        result.setOfficialAccountApplyCountDay(0L);
        result.setOfficialAccountApplyUserCountDay(0L);
        result.setOfficialAccountApplyAmountDay(0L);
        result.setOfficialAccountOrderCountDay(0L);
        result.setOfficialAccountFirstDayOrderCountDay(0L);
        result.setOfficialAccountOrderUserCountDay(0L);
        result.setOfficialAccountOrderAmountDay(0L);
        result.setOfficialAccountFirstDayOrderAmountDay(0L);
        result.setOfficialAccountConsultCountDay(0L);
        result.setOfficialAccountReaderCountDay(0L);
        result.setOfficialAccountCreditApplyUserCountDay(0L);
        result.setOfficialAccountCreditUserCountDay(0L);
        result.setForwardCountDay(0L);
        result.setForwardUserCountDay(0L);
        result.setNoInterestCountDay(0L);
        for (AdDataOfHourODS ods : hourODSList) {
            result.setCostDeviationRateDay(result.getCostDeviationRateDay().add(ods.getCostDeviationRate()));
            result.setCostDay(result.getCostDay() + ods.getCost());
            result.setCompensationAmountDay(result.getCompensationAmountDay() + ods.getCompensationAmount());
            result.setViewCountDay(result.getViewCountDay() + ods.getViewCount());
            result.setValidClickCountDay(result.getValidClickCountDay() + ods.getValidClickCount());
            result.setValuableClickCountDay(result.getValuableClickCountDay() + ods.getValuableClickCount());
            result.setConversionsCountDay(result.getConversionsCountDay() + ods.getConversionsCount());
            result.setDeepConversionsCountDay(result.getDeepConversionsCountDay() + ods.getDeepConversionsCount());
            result.setOrderCountDay(result.getOrderCountDay() + ods.getOrderCount());
            result.setFirstDayOrderCountDay(result.getFirstDayOrderCountDay() + ods.getFirstDayOrderCount());
            result.setOrderAmountDay(result.getOrderAmountDay() + ods.getOrderAmount());
            result.setFirstDayOrderAmountDay(result.getFirstDayOrderAmountDay() + ods.getFirstDayOrderAmount());
            result.setSignInCountDay(result.getSignInCountDay() + ods.getSignInCount());
            result.setScanFollowCountDay(result.getScanFollowCountDay() + ods.getScanFollowCount());
            result.setWechatAppRegisterUvDay(result.getWechatAppRegisterUvDay() + ods.getWechatAppRegisterUv());
            result.setWechatMinigameRetentionCountDay(result.getWechatMinigameRetentionCountDay() + ods.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountDay(result.getWechatMinigameCheckoutCountDay() + ods.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountDay(result.getWechatMinigameCheckoutAmountDay() + ods.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountDay(result.getOfficialAccountFollowCountDay() + ods.getOfficialAccountFollowCount());
            result.setOfficialAccountRegisterUserCountDay(result.getOfficialAccountRegisterUserCountDay() + ods.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterAmountDay(result.getOfficialAccountRegisterAmountDay() + ods.getOfficialAccountRegisterAmount());
            result.setOfficialAccountApplyCountDay(result.getOfficialAccountApplyCountDay() + ods.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountDay(result.getOfficialAccountApplyUserCountDay() + ods.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyAmountDay(result.getOfficialAccountApplyAmountDay() + ods.getOfficialAccountApplyAmount());
            result.setOfficialAccountOrderCountDay(result.getOfficialAccountOrderCountDay() + ods.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(result.getOfficialAccountFirstDayOrderCountDay() + ods.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountDay(result.getOfficialAccountOrderUserCountDay() + ods.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderAmountDay(result.getOfficialAccountOrderAmountDay() + ods.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(result.getOfficialAccountFirstDayOrderAmountDay() + ods.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountConsultCountDay(result.getOfficialAccountConsultCountDay() + ods.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountDay(result.getOfficialAccountReaderCountDay() + ods.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountDay(result.getOfficialAccountCreditApplyUserCountDay() + ods.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountDay(result.getOfficialAccountCreditUserCountDay() + ods.getOfficialAccountCreditUserCount());
            result.setForwardCountDay(result.getForwardCountDay() + ods.getForwardCount());
            result.setForwardUserCountDay(result.getForwardUserCountDay() + ods.getForwardUserCount());
            result.setNoInterestCountDay(result.getNoInterestCountDay() + ods.getNoInterestCount());
        }
        result.setThousandDisplayPriceDay(result.getViewCountDay() == 0 ? 0L : NumberUtil.divideForAd(result.getCostDay(), result.getViewCountDay()).multiply(new BigDecimal(1000)).longValue());
        result.setCtrDay(result.getViewCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValidClickCountDay(), result.getViewCountDay()));
        result.setCpcDay(result.getValidClickCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getValidClickCountDay()));
        result.setValuableClickRateDay(result.getViewCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValuableClickCountDay(), result.getViewCountDay()));
        result.setValuableClickCostDay(result.getValuableClickCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getValuableClickCountDay()));
        result.setConversionsCostDay(result.getConversionsCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getConversionsCountDay()));
        result.setConversionsRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getConversionsCountDay(), result.getValidClickCountDay()));
        result.setDeepConversionsCostDay(result.getDeepConversionsCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getDeepConversionsCountDay()));
        result.setDeepConversionsRateDay(result.getValuableClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getDeepConversionsCountDay(), result.getValuableClickCountDay()));
        result.setWebOrderCostDay(result.getOrderCountDay() == 0 ? 0L : NumberUtil.divideForMoney(result.getCostDay(), result.getOrderCountDay()));
        result.setOrderRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderCountDay(), result.getValidClickCountDay()));
        result.setOrderUnitPriceDay(result.getOrderCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOrderAmountDay(), result.getOrderCountDay()));
        result.setOrderRoiDay(result.getCostDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountDay(), result.getCostDay()));
        result.setWechatMinigameRegisterCostDay(result.getWechatAppRegisterUvDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getWechatAppRegisterUvDay()));
        result.setWechatMinigameRegisterRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getWechatAppRegisterUvDay(), result.getValidClickCountDay()));
        result.setWechatMinigameArpuDay(result.getWechatAppRegisterUvDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountDay(), result.getWechatAppRegisterUvDay()));
        result.setOfficialAccountFollowRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountFollowCountDay(), result.getValidClickCountDay()));
        result.setOfficialAccountRegisterRateDay(result.getOfficialAccountFollowCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountDay(), result.getOfficialAccountFollowCountDay()));
        result.setOfficialAccountRegisterCostDay(result.getOfficialAccountRegisterUserCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountRegisterUserCountDay()));
        result.setOfficialAccountRegisterRoiDay(result.getCostDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountDay(), result.getCostDay()));
        result.setOfficialAccountApplyRateDay(result.getOfficialAccountFollowCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountDay(), result.getOfficialAccountFollowCountDay()));
        result.setOfficialAccountApplyCostDay(result.getOfficialAccountApplyUserCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountApplyUserCountDay()));
        result.setOfficialAccountApplyRoiDay(result.getCostDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountDay(), result.getCostDay()));
        result.setOfficialAccountOrderRateDay(result.getOfficialAccountFollowCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountDay(), result.getOfficialAccountFollowCountDay()));
        result.setOfficialAccountOrderCostDay(result.getOfficialAccountOrderCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountOrderCountDay()));
        result.setOfficialAccountOrderRoiDay(result.getCostDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountDay(), result.getCostDay()));

        // 聚合总数据
        if (yesterdayDWD == null) {
            result.setCostDeviationRateTotal(result.getCostDeviationRateDay());
            result.setCostTotal(result.getCostDay());
            result.setCompensationAmountTotal(result.getCompensationAmountDay());
            result.setViewCountTotal(result.getViewCountDay());
            result.setThousandDisplayPriceAll(result.getThousandDisplayPriceDay());
            result.setValidClickCountTotal(result.getValidClickCountDay());
            result.setCtrAll(result.getCtrDay());
            result.setCpcAll(result.getCpcDay());
            result.setValuableClickCountTotal(result.getValuableClickCountDay());
            result.setValuableClickRateAll(result.getValuableClickRateDay());
            result.setValuableClickCostAll(result.getValuableClickCostDay());
            result.setConversionsCountTotal(result.getConversionsCountDay());
            result.setConversionsCostAll(result.getConversionsCostDay());
            result.setConversionsRateAll(result.getConversionsRateDay());
            result.setDeepConversionsCountTotal(result.getDeepConversionsCountDay());
            result.setDeepConversionsCostAll(result.getDeepConversionsCostDay());
            result.setDeepConversionsRateAll(result.getDeepConversionsRateDay());
            result.setOrderCountTotal(result.getOrderCountDay());
            result.setFirstDayOrderCountTotal(result.getFirstDayOrderCountDay());
            result.setWebOrderCostAll(result.getWebOrderCostDay());
            result.setOrderRateAll(result.getOrderRateDay());
            result.setOrderAmountTotal(result.getOrderAmountDay());
            result.setFirstDayOrderAmountTotal(result.getFirstDayOrderAmountDay());
            result.setOrderUnitPriceAll(result.getOrderUnitPriceDay());
            result.setOrderRoiAll(result.getOrderRoiDay());
            result.setSignInCountTotal(result.getSignInCountDay());
            result.setScanFollowCountTotal(result.getScanFollowCountDay());
            result.setWechatAppRegisterUvTotal(result.getWechatAppRegisterUvDay());
            result.setWechatMinigameRegisterCostAll(result.getWechatMinigameRegisterCostDay());
            result.setWechatMinigameRegisterRateAll(result.getWechatMinigameRegisterRateDay());
            result.setWechatMinigameArpuAll(result.getWechatMinigameArpuDay());
            result.setWechatMinigameRetentionCountTotal(result.getWechatMinigameRetentionCountDay());
            result.setWechatMinigameCheckoutCountTotal(result.getWechatMinigameCheckoutCountDay());
            result.setWechatMinigameCheckoutAmountTotal(result.getWechatMinigameCheckoutAmountDay());
            result.setOfficialAccountFollowCountTotal(result.getOfficialAccountFollowCountDay());
            result.setOfficialAccountFollowRateAll(result.getOfficialAccountFollowRateDay());
            result.setOfficialAccountRegisterUserCountTotal(result.getOfficialAccountRegisterUserCountDay());
            result.setOfficialAccountRegisterRateAll(result.getOfficialAccountRegisterRateDay());
            result.setOfficialAccountRegisterCostAll(result.getOfficialAccountRegisterCostDay());
            result.setOfficialAccountRegisterAmountTotal(result.getOfficialAccountRegisterAmountDay());
            result.setOfficialAccountRegisterRoiAll(result.getOfficialAccountRegisterRoiDay());
            result.setOfficialAccountApplyCountTotal(result.getOfficialAccountApplyCountDay());
            result.setOfficialAccountApplyUserCountTotal(result.getOfficialAccountApplyUserCountDay());
            result.setOfficialAccountApplyRateAll(result.getOfficialAccountApplyRateDay());
            result.setOfficialAccountApplyCostAll(result.getOfficialAccountApplyCostDay());
            result.setOfficialAccountApplyAmountTotal(result.getOfficialAccountApplyAmountDay());
            result.setOfficialAccountApplyRoiAll(result.getOfficialAccountApplyRoiDay());
            result.setOfficialAccountOrderCountTotal(result.getOfficialAccountOrderCountDay());
            result.setOfficialAccountFirstDayOrderCountTotal(result.getOfficialAccountFirstDayOrderCountDay());
            result.setOfficialAccountOrderUserCountTotal(result.getOfficialAccountOrderUserCountDay());
            result.setOfficialAccountOrderRateAll(result.getOfficialAccountOrderRateDay());
            result.setOfficialAccountOrderCostAll(result.getOfficialAccountOrderCostDay());
            result.setOfficialAccountOrderAmountTotal(result.getOfficialAccountOrderAmountDay());
            result.setOfficialAccountFirstDayOrderAmountTotal(result.getOfficialAccountFirstDayOrderAmountDay());
            result.setOfficialAccountOrderRoiAll(result.getOfficialAccountOrderRoiDay());
            result.setOfficialAccountConsultCountTotal(result.getOfficialAccountConsultCountDay());
            result.setOfficialAccountReaderCountTotal(result.getOfficialAccountReaderCountDay());
            result.setOfficialAccountCreditApplyUserCountTotal(result.getOfficialAccountCreditApplyUserCountDay());
            result.setOfficialAccountCreditUserCountTotal(result.getOfficialAccountCreditUserCountDay());
            result.setForwardCountTotal(result.getForwardCountDay());
            result.setForwardUserCountTotal(result.getForwardUserCountDay());
            result.setNoInterestCountTotal(result.getNoInterestCountDay());
        } else {
            result.setCostDeviationRateTotal(yesterdayDWD.getCostDeviationRateTotal().add(result.getCostDeviationRateDay()));
            result.setCostTotal(yesterdayDWD.getCostTotal() + result.getCostDay());
            result.setCompensationAmountTotal(yesterdayDWD.getCompensationAmountTotal() + result.getCompensationAmountDay());
            result.setViewCountTotal(yesterdayDWD.getViewCountTotal() + result.getViewCountDay());
            result.setValuableClickCountTotal(yesterdayDWD.getValuableClickCountTotal() + result.getValuableClickCountDay());
            result.setConversionsCountTotal(yesterdayDWD.getConversionsCountTotal() + result.getConversionsCountDay());
            result.setDeepConversionsCountTotal(yesterdayDWD.getDeepConversionsCountTotal() + result.getDeepConversionsCountDay());
            result.setOrderCountTotal(yesterdayDWD.getOrderCountTotal() + result.getOrderCountDay());
            result.setFirstDayOrderCountTotal(yesterdayDWD.getFirstDayOrderCountTotal() + result.getFirstDayOrderCountDay());
            result.setOrderAmountTotal(yesterdayDWD.getOrderAmountTotal() + result.getOrderAmountDay());
            result.setFirstDayOrderAmountTotal(yesterdayDWD.getFirstDayOrderAmountTotal() + result.getFirstDayOrderAmountDay());
            result.setSignInCountTotal(yesterdayDWD.getSignInCountTotal() + result.getSignInCountDay());
            result.setScanFollowCountTotal(yesterdayDWD.getScanFollowCountTotal() + result.getScanFollowCountDay());
            result.setWechatAppRegisterUvTotal(yesterdayDWD.getWechatAppRegisterUvTotal() + result.getWechatAppRegisterUvDay());
            result.setWechatMinigameRetentionCountTotal(yesterdayDWD.getWechatMinigameRetentionCountTotal() + result.getWechatMinigameRetentionCountDay());
            result.setWechatMinigameCheckoutCountTotal(yesterdayDWD.getWechatMinigameCheckoutCountTotal() + result.getWechatMinigameCheckoutCountDay());
            result.setWechatMinigameCheckoutAmountTotal(yesterdayDWD.getWechatMinigameCheckoutAmountTotal() + result.getWechatMinigameCheckoutAmountDay());
            result.setOfficialAccountFollowCountTotal(yesterdayDWD.getOfficialAccountFollowCountTotal() + result.getOfficialAccountFollowCountDay());
            result.setOfficialAccountRegisterUserCountTotal(yesterdayDWD.getOfficialAccountRegisterUserCountTotal() + result.getOfficialAccountRegisterUserCountDay());
            result.setOfficialAccountRegisterAmountTotal(yesterdayDWD.getOfficialAccountRegisterAmountTotal() + result.getOfficialAccountRegisterAmountDay());
            result.setOfficialAccountApplyCountTotal(yesterdayDWD.getOfficialAccountApplyCountTotal() + result.getOfficialAccountApplyCountDay());
            result.setOfficialAccountApplyUserCountTotal(yesterdayDWD.getOfficialAccountApplyUserCountTotal() + result.getOfficialAccountApplyUserCountDay());
            result.setOfficialAccountApplyAmountTotal(yesterdayDWD.getOfficialAccountApplyAmountTotal() + result.getOfficialAccountApplyAmountDay());
            result.setOfficialAccountOrderCountTotal(yesterdayDWD.getOfficialAccountOrderCountTotal() + result.getOfficialAccountOrderCountDay());
            result.setOfficialAccountFirstDayOrderCountTotal(yesterdayDWD.getOfficialAccountFirstDayOrderCountTotal() + result.getOfficialAccountFirstDayOrderCountDay());
            result.setOfficialAccountOrderUserCountTotal(yesterdayDWD.getOfficialAccountOrderUserCountTotal() + result.getOfficialAccountOrderUserCountDay());
            result.setOfficialAccountOrderAmountTotal(yesterdayDWD.getOfficialAccountOrderAmountTotal() + result.getOfficialAccountOrderAmountDay());
            result.setOfficialAccountFirstDayOrderAmountTotal(yesterdayDWD.getOfficialAccountFirstDayOrderAmountTotal() + result.getOfficialAccountFirstDayOrderAmountDay());
            result.setOfficialAccountConsultCountTotal(yesterdayDWD.getOfficialAccountConsultCountTotal() + result.getOfficialAccountConsultCountDay());
            result.setOfficialAccountReaderCountTotal(yesterdayDWD.getOfficialAccountReaderCountTotal() + result.getOfficialAccountReaderCountDay());
            result.setOfficialAccountCreditApplyUserCountTotal(yesterdayDWD.getOfficialAccountCreditApplyUserCountTotal() + result.getOfficialAccountCreditApplyUserCountDay());
            result.setOfficialAccountCreditUserCountTotal(yesterdayDWD.getOfficialAccountCreditUserCountTotal() + result.getOfficialAccountCreditUserCountDay());
            result.setForwardCountTotal(yesterdayDWD.getForwardCountTotal() + result.getForwardCountDay());
            result.setForwardUserCountTotal(yesterdayDWD.getForwardUserCountTotal() + result.getForwardUserCountDay());
            result.setNoInterestCountTotal(yesterdayDWD.getNoInterestCountTotal() + result.getNoInterestCountDay());

            // 总消耗, 总曝光
            result.setThousandDisplayPriceAll(result.getViewCountTotal() == 0 ? 0L : NumberUtil.divideForAd(result.getCostTotal(), result.getViewCountTotal()).multiply(new BigDecimal(1000)).longValue());
            // 曝光次数, 曝光人数（拿不到曝光人数）
            result.setValidClickCountTotal(yesterdayDWD.getValidClickCountTotal() + result.getValidClickCountDay());
            // 广告点击次数, 广告曝光次数
            result.setCtrAll(result.getViewCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValidClickCountTotal(), result.getViewCountTotal()));
            // 广告花费/广告点击次数
            result.setCpcAll(result.getValidClickCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getValidClickCountTotal()));
            // 广告可转化点击次数/广告曝光次数
            result.setValuableClickRateAll(result.getViewCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValuableClickCountTotal(), result.getViewCountTotal()));
            // 广告花费/可转化点击次数
            result.setValuableClickCostAll(result.getValuableClickCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getValuableClickCountTotal()));
            // 广告花费/转化目标量
            result.setConversionsCostAll(result.getConversionsCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getConversionsCountTotal()));
            // 公众号：转化目标量/点击次数。
            result.setConversionsRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getConversionsCountTotal(), result.getValidClickCountTotal()));
            // 广告花费/深度转化目标量
            result.setDeepConversionsCostAll(result.getDeepConversionsCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getDeepConversionsCountTotal()));
            // 深度转化目标量/可转化点击次数
            result.setDeepConversionsRateAll(result.getValuableClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getDeepConversionsCountTotal(), result.getValuableClickCountTotal()));
            // 广告花费/下单量
            result.setWebOrderCostAll(result.getOrderCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOrderCountTotal()));
            // 下单量/点击次数
            result.setOrderRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderCountTotal(), result.getValidClickCountTotal()));
            // 下单金额/下单量
            result.setOrderUnitPriceAll(result.getOrderCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOrderAmountTotal(), result.getOrderCountTotal()));
            // 下单金额/广告花费
            result.setOrderRoiAll(result.getCostTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountTotal(), result.getCostTotal()));
            // 广告消耗, 小游戏注册人数
            result.setWechatMinigameRegisterCostAll(result.getWechatAppRegisterUvTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getWechatAppRegisterUvTotal()));
            // 小游戏注册人数, 广告点击次数
            result.setWechatMinigameRegisterRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getWechatAppRegisterUvTotal(), result.getValidClickCountTotal()));
            // 总收益, 总人数
            result.setWechatMinigameArpuAll(result.getWechatAppRegisterUvTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountTotal(), result.getWechatAppRegisterUvTotal()));
            // 关注次数, 点击次数
            result.setOfficialAccountFollowRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountFollowCountTotal(), result.getValidClickCountTotal()));
            // 公众号内注册人数, 公众号关注次数
            result.setOfficialAccountRegisterRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
            // 广告消耗, 广告注册人数
            result.setOfficialAccountRegisterCostAll(result.getOfficialAccountRegisterUserCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountRegisterUserCountTotal()));
            // 注册产生的订单金额累计/广告花费
            result.setOfficialAccountRegisterRoiAll(result.getCostTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountTotal(), result.getCostTotal()));
            // 公众号内填单的独立用户数/公众号关注次数
            result.setOfficialAccountApplyRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
            // 广告花费/广告产生的填单行为数量
            result.setOfficialAccountApplyCostAll(result.getOfficialAccountApplyUserCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountApplyUserCountTotal()));
            // 填单产生的订单金额累计/广告花费
            result.setOfficialAccountApplyRoiAll(result.getCostTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountTotal(), result.getCostTotal()));
            // 公众号内下单独立用户数（UV）/公众号关注次数
            result.setOfficialAccountOrderRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
            // 广告花费/广告产生的下单行为数量
            result.setOfficialAccountOrderCostAll(result.getOfficialAccountOrderCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountOrderCountTotal()));
            // 下单产生的订单金额累计/广告花费
            result.setOfficialAccountOrderRoiAll(result.getCostTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountTotal(), result.getCostTotal()));
        }
        return result;
    }

    public static AdStatOfHourDWD byMaxCompute(Record record) {
        AdStatOfHourDWD result = new AdStatOfHourDWD();
        result.setStatDay(ObjectUtil.toString(record.get("stat_day")));
        result.setHour(ObjectUtil.toInt(record.get("hour")));
        result.setAccountId(ObjectUtil.toLong(record.get("account_id")));
        result.setCampaignId(ObjectUtil.toLong(record.get("campaign_id")));
        result.setAgencyAccountId(ObjectUtil.toLong(record.get("agency_account_id")));
        result.setWechatAccountId(ObjectUtil.toString(record.get("wechat_account_id")));
        result.setWechatAgencyId(ObjectUtil.toString(record.get("wechat_agency_id")));
        result.setAdgroupId(ObjectUtil.toLong(record.get("adgroup_id")));
        result.setAdId(ObjectUtil.toLong(record.get("ad_id")));
        result.setCreateTime(ObjectUtil.toDate(record.get("create_time")));
        result.setCostDeviationRateTotal(ObjectUtil.toDecimal(record.get("cost_deviation_rate_total")));
        result.setCostDeviationRateDay(ObjectUtil.toDecimal(record.get("cost_deviation_rate_day")));
        result.setCostDeviationRateHour(ObjectUtil.toDecimal(record.get("cost_deviation_rate_hour")));
        result.setCostTotal(ObjectUtil.toLong(record.get("cost_total")));
        result.setCostDay(ObjectUtil.toLong(record.get("cost_day")));
        result.setCostHour(ObjectUtil.toLong(record.get("cost_hour")));
        result.setCompensationAmountTotal(ObjectUtil.toLong(record.get("compensation_amount_total")));
        result.setCompensationAmountDay(ObjectUtil.toLong(record.get("compensation_amount_day")));
        result.setCompensationAmountHour(ObjectUtil.toLong(record.get("compensation_amount_hour")));
        result.setViewCountTotal(ObjectUtil.toLong(record.get("view_count_total")));
        result.setViewCountDay(ObjectUtil.toLong(record.get("view_count_day")));
        result.setViewCountHour(ObjectUtil.toLong(record.get("view_count_hour")));
        result.setThousandDisplayPriceAll(ObjectUtil.toLong(record.get("thousand_display_price_all")));
        result.setThousandDisplayPriceDay(ObjectUtil.toLong(record.get("thousand_display_price_day")));
        result.setThousandDisplayPriceHour(ObjectUtil.toLong(record.get("thousand_display_price_hour")));
        result.setAvgViewPerUserHour(ObjectUtil.toDecimal(record.get("avg_view_per_user_hour")));
        result.setValidClickCountTotal(ObjectUtil.toLong(record.get("valid_click_count_total")));
        result.setValidClickCountDay(ObjectUtil.toLong(record.get("valid_click_count_day")));
        result.setValidClickCountHour(ObjectUtil.toLong(record.get("valid_click_count_hour")));
        result.setCtrAll(ObjectUtil.toDecimal(record.get("ctr_all")));
        result.setCtrDay(ObjectUtil.toDecimal(record.get("ctr_day")));
        result.setCtrHour(ObjectUtil.toDecimal(record.get("ctr_hour")));
        result.setCpcAll(ObjectUtil.toLong(record.get("cpc_all")));
        result.setCpcDay(ObjectUtil.toLong(record.get("cpc_day")));
        result.setCpcHour(ObjectUtil.toLong(record.get("cpc_hour")));
        result.setValuableClickCountTotal(ObjectUtil.toLong(record.get("valuable_click_count_total")));
        result.setValuableClickCountDay(ObjectUtil.toLong(record.get("valuable_click_count_day")));
        result.setValuableClickCountHour(ObjectUtil.toLong(record.get("valuable_click_count_hour")));
        result.setValuableClickRateAll(ObjectUtil.toDecimal(record.get("valuable_click_rate_all")));
        result.setValuableClickRateDay(ObjectUtil.toDecimal(record.get("valuable_click_rate_day")));
        result.setValuableClickRateHour(ObjectUtil.toDecimal(record.get("valuable_click_rate_hour")));
        result.setValuableClickCostAll(ObjectUtil.toLong(record.get("valuable_click_cost_all")));
        result.setValuableClickCostDay(ObjectUtil.toLong(record.get("valuable_click_cost_day")));
        result.setValuableClickCostHour(ObjectUtil.toLong(record.get("valuable_click_cost_hour")));
        result.setConversionsCountTotal(ObjectUtil.toLong(record.get("conversions_count_total")));
        result.setConversionsCountDay(ObjectUtil.toLong(record.get("conversions_count_day")));
        result.setConversionsCountHour(ObjectUtil.toLong(record.get("conversions_count_hour")));
        result.setConversionsCostAll(ObjectUtil.toLong(record.get("conversions_cost_all")));
        result.setConversionsCostDay(ObjectUtil.toLong(record.get("conversions_cost_day")));
        result.setConversionsCostHour(ObjectUtil.toLong(record.get("conversions_cost_hour")));
        result.setConversionsRateAll(ObjectUtil.toDecimal(record.get("conversions_rate_all")));
        result.setConversionsRateDay(ObjectUtil.toDecimal(record.get("conversions_rate_day")));
        result.setConversionsRateHour(ObjectUtil.toDecimal(record.get("conversions_rate_hour")));
        result.setDeepConversionsCountTotal(ObjectUtil.toLong(record.get("deep_conversions_count_total")));
        result.setDeepConversionsCountDay(ObjectUtil.toLong(record.get("deep_conversions_count_day")));
        result.setDeepConversionsCountHour(ObjectUtil.toLong(record.get("deep_conversions_count_hour")));
        result.setDeepConversionsCostAll(ObjectUtil.toLong(record.get("deep_conversions_cost_all")));
        result.setDeepConversionsCostDay(ObjectUtil.toLong(record.get("deep_conversions_cost_day")));
        result.setDeepConversionsCostHour(ObjectUtil.toLong(record.get("deep_conversions_cost_hour")));
        result.setDeepConversionsRateAll(ObjectUtil.toDecimal(record.get("deep_conversions_rate_all")));
        result.setDeepConversionsRateDay(ObjectUtil.toDecimal(record.get("deep_conversions_rate_day")));
        result.setDeepConversionsRateHour(ObjectUtil.toDecimal(record.get("deep_conversions_rate_hour")));
        result.setOrderCountTotal(ObjectUtil.toLong(record.get("order_count_total")));
        result.setOrderCountDay(ObjectUtil.toLong(record.get("order_count_day")));
        result.setOrderCountHour(ObjectUtil.toLong(record.get("order_count_hour")));
        result.setFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("first_day_order_count_total")));
        result.setFirstDayOrderCountDay(ObjectUtil.toLong(record.get("first_day_order_count_day")));
        result.setFirstDayOrderCountHour(ObjectUtil.toLong(record.get("first_day_order_count_hour")));
        result.setWebOrderCostAll(ObjectUtil.toLong(record.get("web_order_cost_all")));
        result.setWebOrderCostDay(ObjectUtil.toLong(record.get("web_order_cost_day")));
        result.setWebOrderCostHour(ObjectUtil.toLong(record.get("web_order_cost_hour")));
        result.setOrderRateAll(ObjectUtil.toDecimal(record.get("order_rate_all")));
        result.setOrderRateDay(ObjectUtil.toDecimal(record.get("order_rate_day")));
        result.setOrderRateHour(ObjectUtil.toDecimal(record.get("order_rate_hour")));
        result.setOrderAmountTotal(ObjectUtil.toLong(record.get("order_amount_total")));
        result.setOrderAmountDay(ObjectUtil.toLong(record.get("order_amount_day")));
        result.setOrderAmountHour(ObjectUtil.toLong(record.get("order_amount_hour")));
        result.setFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("first_day_order_amount_total")));
        result.setFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("first_day_order_amount_day")));
        result.setFirstDayOrderAmountHour(ObjectUtil.toLong(record.get("first_day_order_amount_hour")));
        result.setOrderUnitPriceAll(ObjectUtil.toLong(record.get("order_unit_price_all")));
        result.setOrderUnitPriceDay(ObjectUtil.toLong(record.get("order_unit_price_day")));
        result.setOrderUnitPriceHour(ObjectUtil.toLong(record.get("order_unit_price_hour")));
        result.setOrderRoiAll(ObjectUtil.toDecimal(record.get("order_roi_all")));
        result.setOrderRoiDay(ObjectUtil.toDecimal(record.get("order_roi_day")));
        result.setOrderRoiHour(ObjectUtil.toDecimal(record.get("order_roi_hour")));
        result.setSignInCountTotal(ObjectUtil.toLong(record.get("sign_in_count_total")));
        result.setSignInCountDay(ObjectUtil.toLong(record.get("sign_in_count_day")));
        result.setSignInCountHour(ObjectUtil.toLong(record.get("sign_in_count_hour")));
        result.setScanFollowCountTotal(ObjectUtil.toLong(record.get("scan_follow_count_total")));
        result.setScanFollowCountDay(ObjectUtil.toLong(record.get("scan_follow_count_day")));
        result.setScanFollowCountHour(ObjectUtil.toLong(record.get("scan_follow_count_hour")));
        result.setWechatAppRegisterUvTotal(ObjectUtil.toLong(record.get("wechat_app_register_uv_total")));
        result.setWechatAppRegisterUvDay(ObjectUtil.toLong(record.get("wechat_app_register_uv_day")));
        result.setWechatAppRegisterUvHour(ObjectUtil.toLong(record.get("wechat_app_register_uv_hour")));
        result.setWechatMinigameRegisterCostAll(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_all")));
        result.setWechatMinigameRegisterCostDay(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_day")));
        result.setWechatMinigameRegisterCostHour(ObjectUtil.toLong(record.get("wechat_minigame_register_cost_hour")));
        result.setWechatMinigameRegisterRateAll(ObjectUtil.toDecimal(record.get("wechat_minigame_register_rate_all")));
        result.setWechatMinigameRegisterRateDay(ObjectUtil.toDecimal(record.get("wechat_minigame_register_rate_day")));
        result.setWechatMinigameRegisterRateHour(ObjectUtil.toDecimal(record.get("wechat_minigame_register_rate_hour")));
        result.setWechatMinigameArpuAll(ObjectUtil.toDecimal(record.get("wechat_minigame_arpu_all")));
        result.setWechatMinigameArpuDay(ObjectUtil.toDecimal(record.get("wechat_minigame_arpu_day")));
        result.setWechatMinigameArpuHour(ObjectUtil.toDecimal(record.get("wechat_minigame_arpu_hour")));
        result.setWechatMinigameRetentionCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_total")));
        result.setWechatMinigameRetentionCountDay(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_day")));
        result.setWechatMinigameRetentionCountHour(ObjectUtil.toLong(record.get("wechat_minigame_retention_count_hour")));
        result.setWechatMinigameCheckoutCountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_total")));
        result.setWechatMinigameCheckoutCountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_day")));
        result.setWechatMinigameCheckoutCountHour(ObjectUtil.toLong(record.get("wechat_minigame_checkout_count_hour")));
        result.setWechatMinigameCheckoutAmountTotal(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_total")));
        result.setWechatMinigameCheckoutAmountDay(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_day")));
        result.setWechatMinigameCheckoutAmountHour(ObjectUtil.toLong(record.get("wechat_minigame_checkout_amount_hour")));
        result.setOfficialAccountFollowCountTotal(ObjectUtil.toLong(record.get("official_account_follow_count_total")));
        result.setOfficialAccountFollowCountDay(ObjectUtil.toLong(record.get("official_account_follow_count_day")));
        result.setOfficialAccountFollowCountHour(ObjectUtil.toLong(record.get("official_account_follow_count_hour")));
        result.setOfficialAccountFollowRateAll(ObjectUtil.toDecimal(record.get("official_account_follow_rate_all")));
        result.setOfficialAccountFollowRateDay(ObjectUtil.toDecimal(record.get("official_account_follow_rate_day")));
        result.setOfficialAccountFollowRateHour(ObjectUtil.toDecimal(record.get("official_account_follow_rate_hour")));
        result.setOfficialAccountRegisterUserCountTotal(ObjectUtil.toLong(record.get("official_account_register_user_count_total")));
        result.setOfficialAccountRegisterUserCountDay(ObjectUtil.toLong(record.get("official_account_register_user_count_day")));
        result.setOfficialAccountRegisterUserCountHour(ObjectUtil.toLong(record.get("official_account_register_user_count_hour")));
        result.setOfficialAccountRegisterRateAll(ObjectUtil.toDecimal(record.get("official_account_register_rate_all")));
        result.setOfficialAccountRegisterRateDay(ObjectUtil.toDecimal(record.get("official_account_register_rate_day")));
        result.setOfficialAccountRegisterRateHour(ObjectUtil.toDecimal(record.get("official_account_register_rate_hour")));
        result.setOfficialAccountRegisterCostAll(ObjectUtil.toLong(record.get("official_account_register_cost_all")));
        result.setOfficialAccountRegisterCostDay(ObjectUtil.toLong(record.get("official_account_register_cost_day")));
        result.setOfficialAccountRegisterCostHour(ObjectUtil.toLong(record.get("official_account_register_cost_hour")));
        result.setOfficialAccountRegisterAmountTotal(ObjectUtil.toLong(record.get("official_account_register_amount_total")));
        result.setOfficialAccountRegisterAmountDay(ObjectUtil.toLong(record.get("official_account_register_amount_day")));
        result.setOfficialAccountRegisterAmountHour(ObjectUtil.toLong(record.get("official_account_register_amount_hour")));
        result.setOfficialAccountRegisterRoiAll(ObjectUtil.toLong(record.get("official_account_register_roi_all")));
        result.setOfficialAccountRegisterRoiDay(ObjectUtil.toLong(record.get("official_account_register_roi_day")));
        result.setOfficialAccountRegisterRoiHour(ObjectUtil.toLong(record.get("official_account_register_roi_hour")));
        result.setOfficialAccountApplyCountTotal(ObjectUtil.toLong(record.get("official_account_apply_count_total")));
        result.setOfficialAccountApplyCountDay(ObjectUtil.toLong(record.get("official_account_apply_count_day")));
        result.setOfficialAccountApplyCountHour(ObjectUtil.toLong(record.get("official_account_apply_count_hour")));
        result.setOfficialAccountApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_apply_user_count_total")));
        result.setOfficialAccountApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_apply_user_count_day")));
        result.setOfficialAccountApplyUserCountHour(ObjectUtil.toLong(record.get("official_account_apply_user_count_hour")));
        result.setOfficialAccountApplyRateAll(ObjectUtil.toDecimal(record.get("official_account_apply_rate_all")));
        result.setOfficialAccountApplyRateDay(ObjectUtil.toDecimal(record.get("official_account_apply_rate_day")));
        result.setOfficialAccountApplyRateHour(ObjectUtil.toDecimal(record.get("official_account_apply_rate_hour")));
        result.setOfficialAccountApplyCostAll(ObjectUtil.toLong(record.get("official_account_apply_cost_all")));
        result.setOfficialAccountApplyCostDay(ObjectUtil.toLong(record.get("official_account_apply_cost_day")));
        result.setOfficialAccountApplyCostHour(ObjectUtil.toLong(record.get("official_account_apply_cost_hour")));
        result.setOfficialAccountApplyAmountTotal(ObjectUtil.toLong(record.get("official_account_apply_amount_total")));
        result.setOfficialAccountApplyAmountDay(ObjectUtil.toLong(record.get("official_account_apply_amount_day")));
        result.setOfficialAccountApplyAmountHour(ObjectUtil.toLong(record.get("official_account_apply_amount_hour")));
        result.setOfficialAccountApplyRoiAll(ObjectUtil.toLong(record.get("official_account_apply_roi_all")));
        result.setOfficialAccountApplyRoiDay(ObjectUtil.toLong(record.get("official_account_apply_roi_day")));
        result.setOfficialAccountApplyRoiHour(ObjectUtil.toLong(record.get("official_account_apply_roi_hour")));
        result.setOfficialAccountOrderCountTotal(ObjectUtil.toLong(record.get("official_account_order_count_total")));
        result.setOfficialAccountOrderCountDay(ObjectUtil.toLong(record.get("official_account_order_count_day")));
        result.setOfficialAccountOrderCountHour(ObjectUtil.toLong(record.get("official_account_order_count_hour")));
        result.setOfficialAccountFirstDayOrderCountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_count_total")));
        result.setOfficialAccountFirstDayOrderCountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_count_day")));
        result.setOfficialAccountFirstDayOrderCountHour(ObjectUtil.toLong(record.get("official_account_first_day_order_count_hour")));
        result.setOfficialAccountOrderUserCountTotal(ObjectUtil.toLong(record.get("official_account_order_user_count_total")));
        result.setOfficialAccountOrderUserCountDay(ObjectUtil.toLong(record.get("official_account_order_user_count_day")));
        result.setOfficialAccountOrderUserCountHour(ObjectUtil.toLong(record.get("official_account_order_user_count_hour")));
        result.setOfficialAccountOrderRateAll(ObjectUtil.toDecimal(record.get("official_account_order_rate_all")));
        result.setOfficialAccountOrderRateDay(ObjectUtil.toDecimal(record.get("official_account_order_rate_day")));
        result.setOfficialAccountOrderRateHour(ObjectUtil.toDecimal(record.get("official_account_order_rate_hour")));
        result.setOfficialAccountOrderCostAll(ObjectUtil.toLong(record.get("official_account_order_cost_all")));
        result.setOfficialAccountOrderCostDay(ObjectUtil.toLong(record.get("official_account_order_cost_day")));
        result.setOfficialAccountOrderCostHour(ObjectUtil.toLong(record.get("official_account_order_cost_hour")));
        result.setOfficialAccountOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_order_amount_total")));
        result.setOfficialAccountOrderAmountDay(ObjectUtil.toLong(record.get("official_account_order_amount_day")));
        result.setOfficialAccountOrderAmountHour(ObjectUtil.toLong(record.get("official_account_order_amount_hour")));
        result.setOfficialAccountFirstDayOrderAmountTotal(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_total")));
        result.setOfficialAccountFirstDayOrderAmountDay(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_day")));
        result.setOfficialAccountFirstDayOrderAmountHour(ObjectUtil.toLong(record.get("official_account_first_day_order_amount_hour")));
        result.setOfficialAccountOrderRoiAll(ObjectUtil.toLong(record.get("official_account_order_roi_all")));
        result.setOfficialAccountOrderRoiDay(ObjectUtil.toLong(record.get("official_account_order_roi_day")));
        result.setOfficialAccountOrderRoiHour(ObjectUtil.toLong(record.get("official_account_order_roi_hour")));
        result.setOfficialAccountConsultCountTotal(ObjectUtil.toLong(record.get("official_account_consult_count_total")));
        result.setOfficialAccountConsultCountDay(ObjectUtil.toLong(record.get("official_account_consult_count_day")));
        result.setOfficialAccountConsultCountHour(ObjectUtil.toLong(record.get("official_account_consult_count_hour")));
        result.setOfficialAccountReaderCountTotal(ObjectUtil.toLong(record.get("official_account_reader_count_total")));
        result.setOfficialAccountReaderCountDay(ObjectUtil.toLong(record.get("official_account_reader_count_day")));
        result.setOfficialAccountReaderCountHour(ObjectUtil.toLong(record.get("official_account_reader_count_hour")));
        result.setOfficialAccountCreditApplyUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_total")));
        result.setOfficialAccountCreditApplyUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_day")));
        result.setOfficialAccountCreditApplyUserCountHour(ObjectUtil.toLong(record.get("official_account_credit_apply_user_count_hour")));
        result.setOfficialAccountCreditUserCountTotal(ObjectUtil.toLong(record.get("official_account_credit_user_count_total")));
        result.setOfficialAccountCreditUserCountDay(ObjectUtil.toLong(record.get("official_account_credit_user_count_day")));
        result.setOfficialAccountCreditUserCountHour(ObjectUtil.toLong(record.get("official_account_credit_user_count_hour")));
        result.setForwardCountTotal(ObjectUtil.toLong(record.get("forward_count_total")));
        result.setForwardCountDay(ObjectUtil.toLong(record.get("forward_count_day")));
        result.setForwardCountHour(ObjectUtil.toLong(record.get("forward_count_hour")));
        result.setForwardUserCountTotal(ObjectUtil.toLong(record.get("forward_user_count_total")));
        result.setForwardUserCountDay(ObjectUtil.toLong(record.get("forward_user_count_day")));
        result.setForwardUserCountHour(ObjectUtil.toLong(record.get("forward_user_count_hour")));
        result.setNoInterestCountTotal(ObjectUtil.toLong(record.get("no_interest_count_total")));
        result.setNoInterestCountDay(ObjectUtil.toLong(record.get("no_interest_count_day")));
        result.setNoInterestCountHour(ObjectUtil.toLong(record.get("no_interest_count_hour")));
        return result;
    }

    public static AdStatOfHourDWD completion(LocalDateTime completionTime, AdStatOfHourDWD lastReduceData) {
        String statDay = DateUtil.formatLocalDate(completionTime.toLocalDate());
        int hour = completionTime.getHour();
        AdStatOfHourDWD result = new AdStatOfHourDWD();
        BeanUtils.copyProperties(lastReduceData, result);
        result.setCreateTime(new Date());
        result.setStatDay(statDay);
        result.setHour(hour);
        AdStatOfHourDWD.initValue(result);

        result.setCostDeviationRateTotal(lastReduceData.getCostDeviationRateTotal());
        result.setCostTotal(lastReduceData.getCostTotal());
        result.setCompensationAmountTotal(lastReduceData.getCompensationAmountTotal());
        result.setViewCountTotal(lastReduceData.getViewCountTotal());
        result.setThousandDisplayPriceAll(lastReduceData.getThousandDisplayPriceAll());
        result.setValidClickCountTotal(lastReduceData.getValidClickCountTotal());
        result.setCtrAll(lastReduceData.getCtrAll());
        result.setCpcAll(lastReduceData.getCpcAll());
        result.setValuableClickCountTotal(lastReduceData.getValuableClickCountTotal());
        result.setValuableClickRateAll(lastReduceData.getValuableClickRateAll());
        result.setValuableClickCostAll(lastReduceData.getValuableClickCostAll());
        result.setConversionsCountTotal(lastReduceData.getConversionsCountTotal());
        result.setConversionsCostAll(lastReduceData.getConversionsCostAll());
        result.setConversionsRateAll(lastReduceData.getConversionsRateAll());
        result.setDeepConversionsCountTotal(lastReduceData.getDeepConversionsCountTotal());
        result.setDeepConversionsCostAll(lastReduceData.getDeepConversionsCostAll());
        result.setDeepConversionsRateAll(lastReduceData.getDeepConversionsRateAll());
        result.setOrderCountTotal(lastReduceData.getOrderCountTotal());
        result.setFirstDayOrderCountTotal(lastReduceData.getFirstDayOrderCountTotal());
        result.setWebOrderCostAll(lastReduceData.getWebOrderCostAll());
        result.setOrderRateAll(lastReduceData.getOrderRateAll());
        result.setOrderAmountTotal(lastReduceData.getOrderAmountTotal());
        result.setFirstDayOrderAmountTotal(lastReduceData.getFirstDayOrderAmountTotal());
        result.setOrderUnitPriceAll(lastReduceData.getOrderUnitPriceAll());
        result.setOrderRoiAll(lastReduceData.getOrderRoiAll());
        result.setSignInCountTotal(lastReduceData.getSignInCountTotal());
        result.setScanFollowCountTotal(lastReduceData.getScanFollowCountTotal());
        result.setWechatAppRegisterUvTotal(lastReduceData.getWechatAppRegisterUvTotal());
        result.setWechatMinigameRegisterCostAll(lastReduceData.getWechatMinigameRegisterCostAll());
        result.setWechatMinigameRegisterRateAll(lastReduceData.getWechatMinigameRegisterRateAll());
        result.setWechatMinigameArpuAll(lastReduceData.getWechatMinigameArpuAll());
        result.setWechatMinigameRetentionCountTotal(lastReduceData.getWechatMinigameRetentionCountTotal());
        result.setWechatMinigameCheckoutCountTotal(lastReduceData.getWechatMinigameCheckoutCountTotal());
        result.setWechatMinigameCheckoutAmountTotal(lastReduceData.getWechatMinigameCheckoutAmountTotal());
        result.setOfficialAccountFollowCountTotal(lastReduceData.getOfficialAccountFollowCountTotal());
        result.setOfficialAccountFollowRateAll(lastReduceData.getOfficialAccountFollowRateAll());
        result.setOfficialAccountRegisterUserCountTotal(lastReduceData.getOfficialAccountRegisterUserCountTotal());
        result.setOfficialAccountRegisterRateAll(lastReduceData.getOfficialAccountRegisterRateAll());
        result.setOfficialAccountRegisterCostAll(lastReduceData.getOfficialAccountRegisterCostAll());
        result.setOfficialAccountRegisterAmountTotal(lastReduceData.getOfficialAccountRegisterAmountTotal());
        result.setOfficialAccountRegisterRoiAll(lastReduceData.getOfficialAccountRegisterRoiAll());
        result.setOfficialAccountApplyCountTotal(lastReduceData.getOfficialAccountApplyCountTotal());
        result.setOfficialAccountApplyUserCountTotal(lastReduceData.getOfficialAccountApplyUserCountTotal());
        result.setOfficialAccountApplyRateAll(lastReduceData.getOfficialAccountApplyRateAll());
        result.setOfficialAccountApplyCostAll(lastReduceData.getOfficialAccountApplyCostAll());
        result.setOfficialAccountApplyAmountTotal(lastReduceData.getOfficialAccountApplyAmountTotal());
        result.setOfficialAccountApplyRoiAll(lastReduceData.getOfficialAccountApplyRoiAll());
        result.setOfficialAccountOrderCountTotal(lastReduceData.getOfficialAccountOrderCountTotal());
        result.setOfficialAccountFirstDayOrderCountTotal(lastReduceData.getOfficialAccountFirstDayOrderCountTotal());
        result.setOfficialAccountOrderUserCountTotal(lastReduceData.getOfficialAccountOrderUserCountTotal());
        result.setOfficialAccountOrderRateAll(lastReduceData.getOfficialAccountOrderRateAll());
        result.setOfficialAccountOrderCostAll(lastReduceData.getOfficialAccountOrderCostAll());
        result.setOfficialAccountOrderAmountTotal(lastReduceData.getOfficialAccountOrderAmountTotal());
        result.setOfficialAccountFirstDayOrderAmountTotal(lastReduceData.getOfficialAccountFirstDayOrderAmountTotal());
        result.setOfficialAccountOrderRoiAll(lastReduceData.getOfficialAccountOrderRoiAll());
        result.setOfficialAccountConsultCountTotal(lastReduceData.getOfficialAccountConsultCountTotal());
        result.setOfficialAccountReaderCountTotal(lastReduceData.getOfficialAccountReaderCountTotal());
        result.setOfficialAccountCreditApplyUserCountTotal(lastReduceData.getOfficialAccountCreditApplyUserCountTotal());
        result.setOfficialAccountCreditUserCountTotal(lastReduceData.getOfficialAccountCreditUserCountTotal());
        result.setForwardCountTotal(lastReduceData.getForwardCountTotal());
        result.setForwardUserCountTotal(lastReduceData.getForwardUserCountTotal());
        result.setNoInterestCountTotal(lastReduceData.getNoInterestCountTotal());
        result.setNoInterestCountHour(lastReduceData.getNoInterestCountHour());

        if (statDay.equals(lastReduceData.getStatDay())) {
            result.setCostDeviationRateDay(lastReduceData.getCostDeviationRateDay());
            result.setCostDay(lastReduceData.getCostDay());
            result.setCompensationAmountDay(lastReduceData.getCompensationAmountDay());
            result.setViewCountDay(lastReduceData.getViewCountDay());
            result.setThousandDisplayPriceDay(lastReduceData.getThousandDisplayPriceDay());
            result.setValidClickCountDay(lastReduceData.getValidClickCountDay());
            result.setCtrDay(lastReduceData.getCtrDay());
            result.setCpcDay(lastReduceData.getCpcDay());
            result.setValuableClickCountDay(lastReduceData.getValuableClickCountDay());
            result.setValuableClickRateDay(lastReduceData.getValuableClickRateDay());
            result.setValuableClickCostDay(lastReduceData.getValuableClickCostDay());
            result.setConversionsCountDay(lastReduceData.getConversionsCountDay());
            result.setConversionsCostDay(lastReduceData.getConversionsCostDay());
            result.setConversionsRateDay(lastReduceData.getConversionsRateDay());
            result.setDeepConversionsCountDay(lastReduceData.getDeepConversionsCountDay());
            result.setDeepConversionsCostDay(lastReduceData.getDeepConversionsCostDay());
            result.setDeepConversionsRateDay(lastReduceData.getDeepConversionsRateDay());
            result.setOrderCountDay(lastReduceData.getOrderCountDay());
            result.setFirstDayOrderCountDay(lastReduceData.getFirstDayOrderCountDay());
            result.setWebOrderCostDay(lastReduceData.getWebOrderCostDay());
            result.setOrderRateDay(lastReduceData.getOrderRateDay());
            result.setOrderAmountDay(lastReduceData.getOrderAmountDay());
            result.setFirstDayOrderAmountDay(lastReduceData.getFirstDayOrderAmountDay());
            result.setOrderUnitPriceDay(lastReduceData.getOrderUnitPriceDay());
            result.setOrderRoiDay(lastReduceData.getOrderRoiDay());
            result.setSignInCountDay(lastReduceData.getSignInCountDay());
            result.setScanFollowCountDay(lastReduceData.getScanFollowCountDay());
            result.setWechatAppRegisterUvDay(lastReduceData.getWechatAppRegisterUvDay());
            result.setWechatMinigameRegisterCostDay(lastReduceData.getWechatMinigameRegisterCostDay());
            result.setWechatMinigameRegisterRateDay(lastReduceData.getWechatMinigameRegisterRateDay());
            result.setWechatMinigameArpuDay(lastReduceData.getWechatMinigameArpuDay());
            result.setWechatMinigameRetentionCountDay(lastReduceData.getWechatMinigameRetentionCountDay());
            result.setWechatMinigameCheckoutCountDay(lastReduceData.getWechatMinigameCheckoutCountDay());
            result.setWechatMinigameCheckoutAmountDay(lastReduceData.getWechatMinigameCheckoutAmountDay());
            result.setOfficialAccountFollowCountDay(lastReduceData.getOfficialAccountFollowCountDay());
            result.setOfficialAccountFollowRateDay(lastReduceData.getOfficialAccountFollowRateDay());
            result.setOfficialAccountRegisterUserCountDay(lastReduceData.getOfficialAccountRegisterUserCountDay());
            result.setOfficialAccountRegisterRateDay(lastReduceData.getOfficialAccountRegisterRateDay());
            result.setOfficialAccountRegisterCostDay(lastReduceData.getOfficialAccountRegisterCostDay());
            result.setOfficialAccountRegisterAmountDay(lastReduceData.getOfficialAccountRegisterAmountDay());
            result.setOfficialAccountRegisterRoiDay(lastReduceData.getOfficialAccountRegisterRoiDay());
            result.setOfficialAccountApplyCountDay(lastReduceData.getOfficialAccountApplyCountDay());
            result.setOfficialAccountApplyUserCountDay(lastReduceData.getOfficialAccountApplyUserCountDay());
            result.setOfficialAccountApplyRateDay(lastReduceData.getOfficialAccountApplyRateDay());
            result.setOfficialAccountApplyCostDay(lastReduceData.getOfficialAccountApplyCostDay());
            result.setOfficialAccountApplyAmountDay(lastReduceData.getOfficialAccountApplyAmountDay());
            result.setOfficialAccountApplyRoiDay(lastReduceData.getOfficialAccountApplyRoiDay());
            result.setOfficialAccountOrderCountDay(lastReduceData.getOfficialAccountOrderCountDay());
            result.setOfficialAccountFirstDayOrderCountDay(lastReduceData.getOfficialAccountFirstDayOrderCountDay());
            result.setOfficialAccountOrderUserCountDay(lastReduceData.getOfficialAccountOrderUserCountDay());
            result.setOfficialAccountOrderRateDay(lastReduceData.getOfficialAccountOrderRateDay());
            result.setOfficialAccountOrderCostDay(lastReduceData.getOfficialAccountOrderCostDay());
            result.setOfficialAccountOrderAmountDay(lastReduceData.getOfficialAccountOrderAmountDay());
            result.setOfficialAccountFirstDayOrderAmountDay(lastReduceData.getOfficialAccountFirstDayOrderAmountDay());
            result.setOfficialAccountOrderRoiDay(lastReduceData.getOfficialAccountOrderRoiDay());
            result.setOfficialAccountConsultCountDay(lastReduceData.getOfficialAccountConsultCountDay());
            result.setOfficialAccountReaderCountDay(lastReduceData.getOfficialAccountReaderCountDay());
            result.setOfficialAccountCreditApplyUserCountDay(lastReduceData.getOfficialAccountCreditApplyUserCountDay());
            result.setOfficialAccountCreditUserCountDay(lastReduceData.getOfficialAccountCreditUserCountDay());
            result.setForwardCountDay(lastReduceData.getForwardCountDay());
            result.setForwardUserCountDay(lastReduceData.getForwardUserCountDay());
            result.setNoInterestCountDay(lastReduceData.getNoInterestCountDay());
        }
        return result;
    }

    public static void initValue(AdStatOfHourDWD bean) {
        bean.setCostDeviationRateTotal(BigDecimal.ZERO);
        bean.setCostDeviationRateDay(BigDecimal.ZERO);
        bean.setCostDeviationRateHour(BigDecimal.ZERO);
        bean.setCostTotal(0L);
        bean.setCostDay(0L);
        bean.setCostHour(0L);
        bean.setCompensationAmountTotal(0L);
        bean.setCompensationAmountDay(0L);
        bean.setCompensationAmountHour(0L);
        bean.setViewCountTotal(0L);
        bean.setViewCountDay(0L);
        bean.setViewCountHour(0L);
        bean.setThousandDisplayPriceAll(0L);
        bean.setThousandDisplayPriceDay(0L);
        bean.setThousandDisplayPriceHour(0L);
        bean.setAvgViewPerUserHour(BigDecimal.ZERO);
        bean.setValidClickCountTotal(0L);
        bean.setValidClickCountDay(0L);
        bean.setValidClickCountHour(0L);
        bean.setCtrAll(BigDecimal.ZERO);
        bean.setCtrDay(BigDecimal.ZERO);
        bean.setCtrHour(BigDecimal.ZERO);
        bean.setCpcAll(0L);
        bean.setCpcDay(0L);
        bean.setCpcHour(0L);
        bean.setValuableClickCountTotal(0L);
        bean.setValuableClickCountDay(0L);
        bean.setValuableClickCountHour(0L);
        bean.setValuableClickRateAll(BigDecimal.ZERO);
        bean.setValuableClickRateDay(BigDecimal.ZERO);
        bean.setValuableClickRateHour(BigDecimal.ZERO);
        bean.setValuableClickCostAll(0L);
        bean.setValuableClickCostDay(0L);
        bean.setValuableClickCostHour(0L);
        bean.setConversionsCountTotal(0L);
        bean.setConversionsCountDay(0L);
        bean.setConversionsCountHour(0L);
        bean.setConversionsCostAll(0L);
        bean.setConversionsCostDay(0L);
        bean.setConversionsCostHour(0L);
        bean.setConversionsRateAll(BigDecimal.ZERO);
        bean.setConversionsRateDay(BigDecimal.ZERO);
        bean.setConversionsRateHour(BigDecimal.ZERO);
        bean.setDeepConversionsCountTotal(0L);
        bean.setDeepConversionsCountDay(0L);
        bean.setDeepConversionsCountHour(0L);
        bean.setDeepConversionsCostAll(0L);
        bean.setDeepConversionsCostDay(0L);
        bean.setDeepConversionsCostHour(0L);
        bean.setDeepConversionsRateAll(BigDecimal.ZERO);
        bean.setDeepConversionsRateDay(BigDecimal.ZERO);
        bean.setDeepConversionsRateHour(BigDecimal.ZERO);
        bean.setOrderCountTotal(0L);
        bean.setOrderCountDay(0L);
        bean.setOrderCountHour(0L);
        bean.setFirstDayOrderCountTotal(0L);
        bean.setFirstDayOrderCountDay(0L);
        bean.setFirstDayOrderCountHour(0L);
        bean.setWebOrderCostAll(0L);
        bean.setWebOrderCostDay(0L);
        bean.setWebOrderCostHour(0L);
        bean.setOrderRateAll(BigDecimal.ZERO);
        bean.setOrderRateDay(BigDecimal.ZERO);
        bean.setOrderRateHour(BigDecimal.ZERO);
        bean.setOrderAmountTotal(0L);
        bean.setOrderAmountDay(0L);
        bean.setOrderAmountHour(0L);
        bean.setFirstDayOrderAmountTotal(0L);
        bean.setFirstDayOrderAmountDay(0L);
        bean.setFirstDayOrderAmountHour(0L);
        bean.setOrderUnitPriceAll(0L);
        bean.setOrderUnitPriceDay(0L);
        bean.setOrderUnitPriceHour(0L);
        bean.setOrderRoiAll(BigDecimal.ZERO);
        bean.setOrderRoiDay(BigDecimal.ZERO);
        bean.setOrderRoiHour(BigDecimal.ZERO);
        bean.setSignInCountTotal(0L);
        bean.setSignInCountDay(0L);
        bean.setSignInCountHour(0L);
        bean.setScanFollowCountTotal(0L);
        bean.setScanFollowCountDay(0L);
        bean.setScanFollowCountHour(0L);
        bean.setWechatAppRegisterUvTotal(0L);
        bean.setWechatAppRegisterUvDay(0L);
        bean.setWechatAppRegisterUvHour(0L);
        bean.setWechatMinigameRegisterCostAll(0L);
        bean.setWechatMinigameRegisterCostDay(0L);
        bean.setWechatMinigameRegisterCostHour(0L);
        bean.setWechatMinigameRegisterRateAll(BigDecimal.ZERO);
        bean.setWechatMinigameRegisterRateDay(BigDecimal.ZERO);
        bean.setWechatMinigameRegisterRateHour(BigDecimal.ZERO);
        bean.setWechatMinigameArpuAll(BigDecimal.ZERO);
        bean.setWechatMinigameArpuDay(BigDecimal.ZERO);
        bean.setWechatMinigameArpuHour(BigDecimal.ZERO);
        bean.setWechatMinigameRetentionCountTotal(0L);
        bean.setWechatMinigameRetentionCountDay(0L);
        bean.setWechatMinigameRetentionCountHour(0L);
        bean.setWechatMinigameCheckoutCountTotal(0L);
        bean.setWechatMinigameCheckoutCountDay(0L);
        bean.setWechatMinigameCheckoutCountHour(0L);
        bean.setWechatMinigameCheckoutAmountTotal(0L);
        bean.setWechatMinigameCheckoutAmountDay(0L);
        bean.setWechatMinigameCheckoutAmountHour(0L);
        bean.setOfficialAccountFollowCountTotal(0L);
        bean.setOfficialAccountFollowCountDay(0L);
        bean.setOfficialAccountFollowCountHour(0L);
        bean.setOfficialAccountFollowRateAll(BigDecimal.ZERO);
        bean.setOfficialAccountFollowRateDay(BigDecimal.ZERO);
        bean.setOfficialAccountFollowRateHour(BigDecimal.ZERO);
        bean.setOfficialAccountRegisterUserCountTotal(0L);
        bean.setOfficialAccountRegisterUserCountDay(0L);
        bean.setOfficialAccountRegisterUserCountHour(0L);
        bean.setOfficialAccountRegisterRateAll(BigDecimal.ZERO);
        bean.setOfficialAccountRegisterRateDay(BigDecimal.ZERO);
        bean.setOfficialAccountRegisterRateHour(BigDecimal.ZERO);
        bean.setOfficialAccountRegisterCostAll(0L);
        bean.setOfficialAccountRegisterCostDay(0L);
        bean.setOfficialAccountRegisterCostHour(0L);
        bean.setOfficialAccountRegisterAmountTotal(0L);
        bean.setOfficialAccountRegisterAmountDay(0L);
        bean.setOfficialAccountRegisterAmountHour(0L);
        bean.setOfficialAccountRegisterRoiAll(0L);
        bean.setOfficialAccountRegisterRoiDay(0L);
        bean.setOfficialAccountRegisterRoiHour(0L);
        bean.setOfficialAccountApplyCountTotal(0L);
        bean.setOfficialAccountApplyCountDay(0L);
        bean.setOfficialAccountApplyCountHour(0L);
        bean.setOfficialAccountApplyUserCountTotal(0L);
        bean.setOfficialAccountApplyUserCountDay(0L);
        bean.setOfficialAccountApplyUserCountHour(0L);
        bean.setOfficialAccountApplyRateAll(BigDecimal.ZERO);
        bean.setOfficialAccountApplyRateDay(BigDecimal.ZERO);
        bean.setOfficialAccountApplyRateHour(BigDecimal.ZERO);
        bean.setOfficialAccountApplyCostAll(0L);
        bean.setOfficialAccountApplyCostDay(0L);
        bean.setOfficialAccountApplyCostHour(0L);
        bean.setOfficialAccountApplyAmountTotal(0L);
        bean.setOfficialAccountApplyAmountDay(0L);
        bean.setOfficialAccountApplyAmountHour(0L);
        bean.setOfficialAccountApplyRoiAll(0L);
        bean.setOfficialAccountApplyRoiDay(0L);
        bean.setOfficialAccountApplyRoiHour(0L);
        bean.setOfficialAccountOrderCountTotal(0L);
        bean.setOfficialAccountOrderCountDay(0L);
        bean.setOfficialAccountOrderCountHour(0L);
        bean.setOfficialAccountFirstDayOrderCountTotal(0L);
        bean.setOfficialAccountFirstDayOrderCountDay(0L);
        bean.setOfficialAccountFirstDayOrderCountHour(0L);
        bean.setOfficialAccountOrderUserCountTotal(0L);
        bean.setOfficialAccountOrderUserCountDay(0L);
        bean.setOfficialAccountOrderUserCountHour(0L);
        bean.setOfficialAccountOrderRateAll(BigDecimal.ZERO);
        bean.setOfficialAccountOrderRateDay(BigDecimal.ZERO);
        bean.setOfficialAccountOrderRateHour(BigDecimal.ZERO);
        bean.setOfficialAccountOrderCostAll(0L);
        bean.setOfficialAccountOrderCostDay(0L);
        bean.setOfficialAccountOrderCostHour(0L);
        bean.setOfficialAccountOrderAmountTotal(0L);
        bean.setOfficialAccountOrderAmountDay(0L);
        bean.setOfficialAccountOrderAmountHour(0L);
        bean.setOfficialAccountFirstDayOrderAmountTotal(0L);
        bean.setOfficialAccountFirstDayOrderAmountDay(0L);
        bean.setOfficialAccountFirstDayOrderAmountHour(0L);
        bean.setOfficialAccountOrderRoiAll(0L);
        bean.setOfficialAccountOrderRoiDay(0L);
        bean.setOfficialAccountOrderRoiHour(0L);
        bean.setOfficialAccountConsultCountTotal(0L);
        bean.setOfficialAccountConsultCountDay(0L);
        bean.setOfficialAccountConsultCountHour(0L);
        bean.setOfficialAccountReaderCountTotal(0L);
        bean.setOfficialAccountReaderCountDay(0L);
        bean.setOfficialAccountReaderCountHour(0L);
        bean.setOfficialAccountCreditApplyUserCountTotal(0L);
        bean.setOfficialAccountCreditApplyUserCountDay(0L);
        bean.setOfficialAccountCreditApplyUserCountHour(0L);
        bean.setOfficialAccountCreditUserCountTotal(0L);
        bean.setOfficialAccountCreditUserCountDay(0L);
        bean.setOfficialAccountCreditUserCountHour(0L);
        bean.setForwardCountTotal(0L);
        bean.setForwardCountDay(0L);
        bean.setForwardCountHour(0L);
        bean.setForwardUserCountTotal(0L);
        bean.setForwardUserCountDay(0L);
        bean.setForwardUserCountHour(0L);
        bean.setNoInterestCountTotal(0L);
        bean.setNoInterestCountDay(0L);
        bean.setNoInterestCountHour(0L);
    }
}
