package flink.zanxiangnet.ad.monitoring.process;

import flink.zanxiangnet.ad.monitoring.pojo.entity.AdDataOfDayODS;
import flink.zanxiangnet.ad.monitoring.pojo.entity.AdStatOfDayDWD;
import flink.zanxiangnet.ad.monitoring.util.StateTtlUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.flink.api.common.state.ValueState;
import org.apache.flink.api.common.state.ValueStateDescriptor;
import org.apache.flink.api.common.time.Time;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.KeyedProcessFunction;
import org.apache.flink.util.Collector;

@Slf4j
public class AdDayDWDRollYearProcess extends KeyedProcessFunction<Long, AdDataOfDayODS, AdStatOfDayDWD> {
    // 上次聚合的结果
    private ValueState<AdStatOfDayDWD> lastReduceState;

    public void open(Configuration conf) {
        ValueStateDescriptor<AdStatOfDayDWD> lastReduceStateDescriptor = new ValueStateDescriptor<>("lastReduceState", AdStatOfDayDWD.class);
        lastReduceStateDescriptor.enableTimeToLive(StateTtlUtil.rocketDBTtl(Time.hours(6)));
        lastReduceState = getRuntimeContext().getState(lastReduceStateDescriptor);
    }

    @Override
    public void processElement(AdDataOfDayODS element, KeyedProcessFunction<Long, AdDataOfDayODS, AdStatOfDayDWD>.Context context, Collector<AdStatOfDayDWD> collector) throws Exception {
        AdStatOfDayDWD newStatDWD = AdStatOfDayDWD.reduce(lastReduceState.value(), element, System.currentTimeMillis());
        lastReduceState.update(newStatDWD);
        collector.collect(newStatDWD);
    }
}
