package flink.zanxiangnet.ad.monitoring.sink;

import com.aliyun.odps.tunnel.TunnelException;
import flink.zanxiangnet.ad.monitoring.config.MysqlDataSourceFactory;
import flink.zanxiangnet.ad.monitoring.dao.mapper.AdStatOfDayDWDMapper;
import flink.zanxiangnet.ad.monitoring.pojo.entity.AdStatOfDayDWD;
import flink.zanxiangnet.ad.monitoring.pojo.properties.ApplicationProperties;
import lombok.extern.slf4j.Slf4j;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.sink.RichSinkFunction;
import org.apache.ibatis.datasource.DataSourceFactory;
import org.apache.ibatis.mapping.Environment;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.apache.ibatis.session.SqlSessionFactoryBuilder;
import org.apache.ibatis.transaction.jdbc.JdbcTransactionFactory;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.util.*;

/**
 * 批量数据写出
 */
@Slf4j
public class AdDayDWDToDBBatchSink extends RichSinkFunction<List<AdStatOfDayDWD>> {

    private SqlSessionFactory sqlSessionFactory;


    @Override
    public void open(Configuration config) throws Exception {
        Map<String, String> params = getRuntimeContext()
                .getExecutionConfig()
                .getGlobalJobParameters()
                .toMap();

        Properties mysqlProps = new Properties();
        mysqlProps.setProperty(ApplicationProperties.MYSQL_DRIVER_CLASS_NAME, params.get(ApplicationProperties.MYSQL_DRIVER_CLASS_NAME));
        mysqlProps.setProperty(ApplicationProperties.MYSQL_URL, params.get(ApplicationProperties.MYSQL_URL));
        mysqlProps.setProperty(ApplicationProperties.MYSQL_USERNAME, params.get(ApplicationProperties.MYSQL_USERNAME));
        mysqlProps.setProperty(ApplicationProperties.MYSQL_PASSWORD, params.get(ApplicationProperties.MYSQL_PASSWORD));
        mysqlProps.setProperty(ApplicationProperties.MYSQL_INIT_POOL_SIZE, params.get(ApplicationProperties.MYSQL_INIT_POOL_SIZE));
        mysqlProps.setProperty(ApplicationProperties.MYSQL_MAX_POOL_SIZE, params.get(ApplicationProperties.MYSQL_MAX_POOL_SIZE));

        DataSourceFactory dataSourceFactory = new MysqlDataSourceFactory();
        dataSourceFactory.setProperties(mysqlProps);
        Environment environment = new Environment("mysql", new JdbcTransactionFactory(), dataSourceFactory.getDataSource());
        org.apache.ibatis.session.Configuration configuration = new org.apache.ibatis.session.Configuration(environment);
        // 开启驼峰规则
        configuration.setMapUnderscoreToCamelCase(true);
        configuration.getTypeAliasRegistry().registerAlias(AdStatOfDayDWD.class);
        // addMapper一定要放到 alias的后面！！！！！
        configuration.addMapper(AdStatOfDayDWDMapper.class);
        sqlSessionFactory = new SqlSessionFactoryBuilder().build(configuration);
    }

    /**
     * 将值写入到 Sink。每个值都会调用此函数
     *
     * @param value
     * @param context
     */
    @Override
    public void invoke(List<AdStatOfDayDWD> value, Context context) throws TunnelException, IOException, InvocationTargetException, IllegalAccessException {
        try (SqlSession session = sqlSessionFactory.openSession()) {
            AdStatOfDayDWDMapper mapper = session.getMapper(AdStatOfDayDWDMapper.class);
            mapper.addBatch(value);
            session.commit();
        }
    }

    @Override
    public void close() throws Exception {
        super.close();
    }
}
