package flink.zanxiangnet.ad.monitoring.sink;

import com.aliyun.odps.tunnel.TunnelException;
import flink.zanxiangnet.ad.monitoring.config.ClickhouseDataSourceFactory;
import flink.zanxiangnet.ad.monitoring.dao.mapper.CostMinuterDMMapper;
import flink.zanxiangnet.ad.monitoring.pojo.entity.CostMinuterDM;
import flink.zanxiangnet.ad.monitoring.pojo.properties.ApplicationProperties;
import lombok.extern.slf4j.Slf4j;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.sink.RichSinkFunction;
import org.apache.ibatis.datasource.DataSourceFactory;
import org.apache.ibatis.mapping.Environment;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.apache.ibatis.session.SqlSessionFactoryBuilder;
import org.apache.ibatis.transaction.jdbc.JdbcTransactionFactory;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.util.List;
import java.util.Map;
import java.util.Properties;

/**
 * 批量数据写出
 */
@Slf4j
public class AdMinuteDMToCkBatchSink extends RichSinkFunction<List<CostMinuterDM>> {

    private SqlSessionFactory sqlSessionFactory;


    @Override
    public void open(Configuration config) throws Exception {
        Map<String, String> params = getRuntimeContext()
                .getExecutionConfig()
                .getGlobalJobParameters()
                .toMap();

        Properties ckProps = new Properties();
        ckProps.setProperty(ApplicationProperties.CK_URL, params.get(ApplicationProperties.CK_URL));
        ckProps.setProperty(ApplicationProperties.CK_USERNAME, params.get(ApplicationProperties.CK_USERNAME));
        ckProps.setProperty(ApplicationProperties.CK_PASSWORD, params.get(ApplicationProperties.CK_PASSWORD));

        DataSourceFactory dataSourceFactory = new ClickhouseDataSourceFactory();
        dataSourceFactory.setProperties(ckProps);
        Environment environment = new Environment("clickhouse", new JdbcTransactionFactory(), dataSourceFactory.getDataSource());
        org.apache.ibatis.session.Configuration configuration = new org.apache.ibatis.session.Configuration(environment);
        // 开启驼峰规则
        configuration.setMapUnderscoreToCamelCase(true);
        configuration.getTypeAliasRegistry().registerAlias(CostMinuterDM.class);
        // addMapper一定要放到 alias的后面！！！！！
        configuration.addMapper(CostMinuterDMMapper.class);
        sqlSessionFactory = new SqlSessionFactoryBuilder().build(configuration);
    }

    /**
     * 将值写入到 Sink。每个值都会调用此函数
     *
     * @param value
     * @param context
     */
    @Override
    public void invoke(List<CostMinuterDM> value, Context context) throws TunnelException, IOException, InvocationTargetException, IllegalAccessException {
        try (SqlSession session = sqlSessionFactory.openSession()) {
            CostMinuterDMMapper mapper = session.getMapper(CostMinuterDMMapper.class);
            mapper.addBatch(value);
        }
    }

    @Override
    public void close() throws Exception {
        super.close();
    }
}
