package flink.zanxiangnet.ad.monitoring.stream;

import com.google.common.collect.Lists;
import flink.zanxiangnet.ad.monitoring.trigger.TimerCountTrigger;
import org.apache.flink.api.common.eventtime.SerializableTimestampAssigner;
import org.apache.flink.api.common.eventtime.WatermarkStrategy;
import org.apache.flink.streaming.api.datastream.DataStream;
import org.apache.flink.streaming.api.datastream.SingleOutputStreamOperator;
import org.apache.flink.streaming.api.functions.windowing.AllWindowFunction;
import org.apache.flink.streaming.api.windowing.assigners.TumblingEventTimeWindows;
import org.apache.flink.streaming.api.windowing.time.Time;
import org.apache.flink.streaming.api.windowing.windows.TimeWindow;
import org.apache.flink.util.Collector;

import java.util.List;

public class BatchStream<T> {

    private final DataStream<T> stream;
    // 缓存刷新的间隔时间
    private final Time bufferRefreshTime;
    // 缓存的最大数据量
    private final Long maxBufferCount;

    public BatchStream(DataStream<T> stream, Long maxBufferCount, Time bufferRefreshTime) {
        this.stream = stream;
        this.bufferRefreshTime = bufferRefreshTime;
        this.maxBufferCount = maxBufferCount;
    }

    public SingleOutputStreamOperator<List<T>> toBatch() {
        return stream.assignTimestampsAndWatermarks(WatermarkStrategy.<T>forMonotonousTimestamps()
                        .withTimestampAssigner((SerializableTimestampAssigner<T>) (element, recordTimestamp) -> System.currentTimeMillis()))
                .windowAll(TumblingEventTimeWindows.of(bufferRefreshTime))
                .trigger(new TimerCountTrigger<>(maxBufferCount, bufferRefreshTime))
                // 这里不能使用 lambda表达式，flink无法推测类型
                .apply(new AllWindowFunction<T, List<T>, TimeWindow>() {
                    @Override
                    public void apply(TimeWindow window, Iterable<T> iterable, Collector<List<T>> collector) throws Exception {
                        collector.collect(Lists.newArrayList(iterable));
                    }
                });
    }
}
