package flink.zanxiangnet.ad.monitoring.trigger;

import flink.zanxiangnet.ad.monitoring.pojo.entity.AdDataOfMinuteODS;
import com.zanxiangnet.module.util.DateUtil;
import org.apache.flink.streaming.api.windowing.triggers.Trigger;
import org.apache.flink.streaming.api.windowing.triggers.TriggerResult;
import org.apache.flink.streaming.api.windowing.windows.TimeWindow;

import java.time.LocalDateTime;

public class AdMinuteODSStreamTrigger extends Trigger<AdDataOfMinuteODS, TimeWindow> {
    /**
     * @param adDataOfMinuteODS
     * @param time              此处指 eventTime
     * @param timeWindow        start：窗口开始时间，end：窗口关闭时间，maxTimestamp：能接收到数据的的最大时间
     * @param triggerContext    currentWatermark：当前水印时间，第一个元素进入的时候为 Long.MAX
     * @return CONTINUE:什么都不干，FIRE：触发计算，PURGE：清理窗口元素，FIRE_AND_PURGE：触发计算然后清理窗口元素
     * @throws Exception
     */
    @Override
    public TriggerResult onElement(AdDataOfMinuteODS adDataOfMinuteODS, long time, TimeWindow timeWindow, TriggerContext triggerContext) throws Exception {
        LocalDateTime beginDateTime = DateUtil.milliToLocalDateTime(timeWindow.getStart());
        if (adDataOfMinuteODS.getHour() == beginDateTime.getHour()) {
            return TriggerResult.FIRE_AND_PURGE;
        }
        // 用来做数据回滚及预生成数据
        if(beginDateTime.getHour() > 0) {
            return TriggerResult.FIRE;
        }
        return TriggerResult.CONTINUE;
    }

    @Override
    public TriggerResult onProcessingTime(long time, TimeWindow timeWindow, TriggerContext triggerContext) throws Exception {
        return TriggerResult.CONTINUE;
    }

    /**
     * @param time           eventTime
     * @param timeWindow
     * @param triggerContext
     * @return
     * @throws Exception
     */
    @Override
    public TriggerResult onEventTime(long time, TimeWindow timeWindow, TriggerContext triggerContext) throws Exception {
        return TriggerResult.PURGE;
    }

    @Override
    public void clear(TimeWindow timeWindow, TriggerContext triggerContext) throws Exception {
    }
}
